@@ -22,8 +22,6 @@ from osc_lib import exceptions
 from osc_lib import utils
 
 from openstackclient.i18n import _
-from openstackclient.network import sdk_utils
-
 
 LOG = logging.getLogger(__name__)
 
@@ -52,7 +50,12 @@ def _get_network_columns(item):
         'is_admin_state_up': 'admin_state_up',
         'is_alive': 'alive',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location', 'name', 'tenant_id']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 class AddNetworkToAgent(command.Command):
@@ -165,11 +168,11 @@ class ListNetworkAgent(command.Lister):
             metavar='<agent-type>',
             choices=["bgp", "dhcp", "open-vswitch", "linux-bridge", "ofa",
                      "l3", "loadbalancer", "metering", "metadata", "macvtap",
-                     "nic"],
+                     "nic", "baremetal"],
             help=_("List only agents with the specified agent type. "
                    "The supported agent types are: bgp, dhcp, open-vswitch, "
                    "linux-bridge, ofa, l3, loadbalancer, metering, "
-                   "metadata, macvtap, nic.")
+                   "metadata, macvtap, nic, baremetal.")
         )
         parser.add_argument(
             '--host',
@@ -228,7 +231,8 @@ class ListNetworkAgent(command.Lister):
             'metering': 'Metering agent',
             'metadata': 'Metadata agent',
             'macvtap': 'Macvtap agent',
-            'nic': 'NIC Switch agent'
+            'nic': 'NIC Switch agent',
+            'baremetal': 'Baremetal Node'
         }
 
         filters = {}
