@@ -18,38 +18,39 @@ import copy
 import json
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
+from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-from openstackclient.network.v2 import _tag
-
 
 LOG = logging.getLogger(__name__)
 
 
-def _format_admin_state(state):
-    return 'UP' if state else 'DOWN'
+class AdminStateColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        return 'UP' if self._value else 'DOWN'
 
 
 _formatters = {
-    'admin_state_up': _format_admin_state,
-    'is_admin_state_up': _format_admin_state,
-    'allowed_address_pairs': utils.format_list_of_dicts,
-    'binding_profile': utils.format_dict,
-    'binding_vif_details': utils.format_dict,
-    'binding:profile': utils.format_dict,
-    'binding:vif_details': utils.format_dict,
-    'dns_assignment': utils.format_list_of_dicts,
-    'extra_dhcp_opts': utils.format_list_of_dicts,
-    'fixed_ips': utils.format_list_of_dicts,
-    'security_group_ids': utils.format_list,
-    'tags': utils.format_list,
+    'admin_state_up': AdminStateColumn,
+    'is_admin_state_up': AdminStateColumn,
+    'allowed_address_pairs': format_columns.ListDictColumn,
+    'binding_profile': format_columns.DictColumn,
+    'binding_vif_details': format_columns.DictColumn,
+    'binding:profile': format_columns.DictColumn,
+    'binding:vif_details': format_columns.DictColumn,
+    'dns_assignment': format_columns.ListDictColumn,
+    'extra_dhcp_opts': format_columns.ListDictColumn,
+    'fixed_ips': format_columns.ListDictColumn,
+    'security_group_ids': format_columns.ListColumn,
+    'tags': format_columns.ListColumn,
 }
 
 
@@ -62,9 +63,13 @@ def _get_columns(item):
         'binding:vnic_type': 'binding_vnic_type',
         'is_admin_state_up': 'admin_state_up',
         'is_port_security_enabled': 'port_security_enabled',
-        'tenant_id': 'project_id',
     }
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(item, column_map)
+    hidden_columns = ['location', 'tenant_id']
+    return utils.get_osc_show_columns_for_sdk_resource(
+        item,
+        column_map,
+        hidden_columns
+    )
 
 
 class JSONKeyValueAction(argparse.Action):
@@ -96,21 +101,6 @@ class JSONKeyValueAction(argparse.Action):
 def _get_attrs(client_manager, parsed_args):
     attrs = {}
 
-    # Handle deprecated options
-    # NOTE(dtroyer): --device-id and --host-id were deprecated in Mar 2016.
-    #                Do not remove before 3.x release or Mar 2017.
-    if parsed_args.device_id:
-        attrs['device_id'] = parsed_args.device_id
-        LOG.warning(_(
-            'The --device-id option is deprecated, '
-            'please use --device instead.'
-        ))
-    if parsed_args.host_id:
-        attrs['binding:host_id'] = parsed_args.host_id
-        LOG.warning(_(
-            'The --host-id option is deprecated, '
-            'please use --host instead.'
-        ))
     if parsed_args.description is not None:
         attrs['description'] = parsed_args.description
     if parsed_args.device:
@@ -148,7 +138,7 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
 
     if parsed_args.disable_port_security:
         attrs['port_security_enabled'] = False
@@ -170,6 +160,19 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.disable_uplink_status_propagation):
         attrs['propagate_uplink_status'] = False
 
+    if ('numa_policy_required' in parsed_args and
+            parsed_args.numa_policy_required):
+        attrs['numa_affinity_policy'] = 'required'
+    elif ('numa_policy_preferred' in parsed_args and
+          parsed_args.numa_policy_preferred):
+        attrs['numa_affinity_policy'] = 'preferred'
+    elif ('numa_policy_legacy' in parsed_args and
+          parsed_args.numa_policy_legacy):
+        attrs['numa_affinity_policy'] = 'legacy'
+
+    if 'device_profile' in parsed_args and parsed_args.device_profile:
+        attrs['device_profile'] = parsed_args.device_profile
+
     return attrs
 
 
@@ -235,19 +238,11 @@ def _add_updatable_args(parser):
         metavar='<description>',
         help=_("Description of this port")
     )
-    # NOTE(dtroyer): --device-id is deprecated in Mar 2016.  Do not
-    #                remove before 3.x release or Mar 2017.
-    device_group = parser.add_mutually_exclusive_group()
-    device_group.add_argument(
+    parser.add_argument(
         '--device',
         metavar='<device-id>',
         help=_("Port device ID")
     )
-    device_group.add_argument(
-        '--device-id',
-        metavar='<device-id>',
-        help=argparse.SUPPRESS,
-    )
     parser.add_argument(
         '--mac-address',
         metavar='<mac-address>',
@@ -262,25 +257,22 @@ def _add_updatable_args(parser):
     parser.add_argument(
         '--vnic-type',
         metavar='<vnic-type>',
-        choices=['direct', 'direct-physical', 'macvtap',
-                 'normal', 'baremetal', 'virtio-forwarder'],
-        help=_("VNIC type for this port (direct | direct-physical | "
-               "macvtap | normal | baremetal | virtio-forwarder, "
-               "default: normal)")
+        choices=(
+            'direct', 'direct-physical', 'macvtap',
+            'normal', 'baremetal', 'virtio-forwarder', 'vdpa', 'remote-managed'
+        ),
+        help=_(
+            "VNIC type for this port (direct | direct-physical | "
+            "macvtap | normal | baremetal | virtio-forwarder | vdpa | "
+            "remote-managed, "
+            "default: normal)"
+        ),
     )
-    # NOTE(dtroyer): --host-id is deprecated in Mar 2016.  Do not
-    #                remove before 3.x release or Mar 2017.
-    host_group = parser.add_mutually_exclusive_group()
-    host_group.add_argument(
+    parser.add_argument(
         '--host',
         metavar='<host-id>',
         help=_("Allocate port on host <host-id> (ID only)")
     )
-    host_group.add_argument(
-        '--host-id',
-        metavar='<host-id>',
-        help=argparse.SUPPRESS,
-    )
     parser.add_argument(
         '--dns-domain',
         metavar='dns-domain',
@@ -293,6 +285,22 @@ def _add_updatable_args(parser):
         help=_("Set DNS name for this port "
                "(requires DNS integration extension)")
     )
+    numa_affinity_policy_group = parser.add_mutually_exclusive_group()
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-required',
+        action='store_true',
+        help=_("NUMA affinity policy required to schedule this port")
+    )
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-preferred',
+        action='store_true',
+        help=_("NUMA affinity policy preferred to schedule this port")
+    )
+    numa_affinity_policy_group.add_argument(
+        '--numa-policy-legacy',
+        action='store_true',
+        help=_("NUMA affinity policy using legacy mode to schedule this port")
+    )
 
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
@@ -308,7 +316,20 @@ def _convert_address_pairs(parsed_args):
     return ops
 
 
-class CreatePort(command.ShowOne):
+def _convert_extra_dhcp_options(parsed_args):
+    dhcp_options = []
+    for opt in parsed_args.extra_dhcp_options:
+        option = {}
+        option['opt_name'] = opt['name']
+        if 'value' in opt:
+            option['opt_value'] = opt['value']
+        if 'ip-version' in opt:
+            option['ip_version'] = opt['ip-version']
+        dhcp_options.append(option)
+    return dhcp_options
+
+
+class CreatePort(command.ShowOne, common.NeutronCommandWithExtraArgs):
     _description = _("Create a new port")
 
     def get_parser(self, prog_name):
@@ -378,8 +399,18 @@ class CreatePort(command.ShowOne):
             metavar='<name>',
             help=_("Name of this port")
         )
-        # TODO(singhj): Add support for extended options:
-        # dhcp
+        parser.add_argument(
+            '--extra-dhcp-option',
+            metavar='name=<name>[,value=<value>,ip-version={4,6}]',
+            default=[],
+            action=parseractions.MultiKeyValueCommaAction,
+            dest='extra_dhcp_options',
+            required_keys=['name'],
+            optional_keys=['value', "ip-version"],
+            help=_('Extra DHCP options to be assigned to this port: '
+                   'name=<name>[,value=<value>,ip-version={4,6}] '
+                   '(repeat option to set multiple extra DHCP options)'))
+
         secgroups = parser.add_mutually_exclusive_group()
         secgroups.add_argument(
             '--security-group',
@@ -422,6 +453,11 @@ class CreatePort(command.ShowOne):
                    "ip-address=<ip-address>[,mac-address=<mac-address>] "
                    "(repeat option to set multiple allowed-address pairs)")
         )
+        parser.add_argument(
+            '--device-profile',
+            metavar='<device-profile>',
+            help=_('Cyborg port device profile')
+        )
         _tag.add_tag_option_to_parser_for_create(parser, _('port'))
         return parser
 
@@ -453,15 +489,32 @@ class CreatePort(command.ShowOne):
             attrs['allowed_address_pairs'] = (
                 _convert_address_pairs(parsed_args))
 
+        if parsed_args.extra_dhcp_options:
+            attrs["extra_dhcp_opts"] = _convert_extra_dhcp_options(parsed_args)
+
         if parsed_args.qos_policy:
             attrs['qos_policy_id'] = client.find_qos_policy(
                 parsed_args.qos_policy, ignore_missing=False).id
+
+        set_tags_in_post = bool(
+            client.find_extension('tag-ports-during-bulk-creation'))
+        if set_tags_in_post:
+            if parsed_args.no_tag:
+                attrs['tags'] = []
+            if parsed_args.tags:
+                attrs['tags'] = list(set(parsed_args.tags))
+
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         with common.check_missing_extension_if_error(
                 self.app.client_manager.network, attrs):
             obj = client.create_port(**attrs)
 
-        # tags cannot be set when created, so tags need to be set later.
-        _tag.update_tags_for_set(client, obj, parsed_args)
+        if not set_tags_in_post:
+            # tags cannot be set when created, so tags need to be set later.
+            _tag.update_tags_for_set(client, obj, parsed_args)
+
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
@@ -516,6 +569,10 @@ class ListPort(command.Lister):
                    "This is the entity that uses the port (for example, "
                    "network:dhcp).")
         )
+        parser.add_argument(
+            '--host',
+            metavar='<host-id>',
+            help=_("List only ports bound to this host ID"))
         parser.add_argument(
             '--network',
             metavar='<network>',
@@ -553,6 +610,18 @@ class ListPort(command.Lister):
             metavar='<project>',
             help=_("List ports according to their project (name or ID)")
         )
+        parser.add_argument(
+            '--name',
+            metavar='<name>',
+            help=_("List ports according to their name")
+        )
+        parser.add_argument(
+            '--security-group',
+            action='append',
+            dest='security_groups',
+            metavar='<security-group>',
+            help=_("List only ports associated with this security group")
+        )
         identity_common.add_project_domain_option_to_parser(parser)
         parser.add_argument(
             '--fixed-ip',
@@ -604,6 +673,8 @@ class ListPort(command.Lister):
             server = utils.find_resource(compute_client.servers,
                                          parsed_args.server)
             filters['device_id'] = server.id
+        if parsed_args.host:
+            filters['binding:host_id'] = parsed_args.host
         if parsed_args.network:
             network = network_client.find_network(parsed_args.network,
                                                   ignore_missing=False)
@@ -616,15 +687,18 @@ class ListPort(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            filters['tenant_id'] = project_id
             filters['project_id'] = project_id
+        if parsed_args.name:
+            filters['name'] = parsed_args.name
         if parsed_args.fixed_ip:
             filters['fixed_ips'] = _prepare_filter_fixed_ips(
                 self.app.client_manager, parsed_args)
+        if parsed_args.security_groups:
+            filters['security_groups'] = parsed_args.security_groups
 
         _tag.get_tag_filtering_args(parsed_args, filters)
 
-        data = network_client.ports(**filters)
+        data = network_client.ports(fields=columns, **filters)
 
         headers, attrs = utils.calculate_header_and_attrs(
             column_headers, columns, parsed_args)
@@ -637,7 +711,7 @@ class ListPort(command.Lister):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class SetPort(command.Command):
+class SetPort(common.NeutronCommandWithExtraArgs):
     _description = _("Set port properties")
 
     def get_parser(self, prog_name):
@@ -746,6 +820,17 @@ class SetPort(command.Command):
                    "(Specify both --allowed-address and --no-allowed-address "
                    "to overwrite the current allowed-address pairs)")
         )
+        parser.add_argument(
+            '--extra-dhcp-option',
+            metavar='name=<name>[,value=<value>,ip-version={4,6}]',
+            default=[],
+            action=parseractions.MultiKeyValueCommaAction,
+            dest='extra_dhcp_options',
+            required_keys=['name'],
+            optional_keys=['value', "ip-version"],
+            help=_('Extra DHCP options to be assigned to this port: '
+                   'name=<name>[,value=<value>,ip-version={4,6}] '
+                   '(repeat option to set multiple extra DHCP options)'))
         parser.add_argument(
             '--data-plane-status',
             metavar='<status>',
@@ -808,9 +893,16 @@ class SetPort(command.Command):
             attrs['allowed_address_pairs'].extend(
                 _convert_address_pairs(parsed_args)
             )
+
+        if parsed_args.extra_dhcp_options:
+            attrs["extra_dhcp_opts"] = _convert_extra_dhcp_options(parsed_args)
+
         if parsed_args.data_plane_status:
             attrs['data_plane_status'] = parsed_args.data_plane_status
 
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
+
         if attrs:
             with common.check_missing_extension_if_error(
                     self.app.client_manager.network, attrs):
@@ -842,7 +934,7 @@ class ShowPort(command.ShowOne):
 
 # TODO(abhiraut): Use the SDK resource mapped attribute names once the
 # OSC minimum requirements include SDK 1.0.
-class UnsetPort(command.Command):
+class UnsetPort(common.NeutronUnsetCommandWithExtraArgs):
     _description = _("Unset port properties")
 
     def get_parser(self, prog_name):
@@ -900,6 +992,17 @@ class UnsetPort(command.Command):
             action='store_true',
             help=_("Clear existing information of data plane status")
         )
+        parser.add_argument(
+            '--numa-policy',
+            action='store_true',
+            help=_("Clear existing NUMA affinity policy")
+        )
+        parser.add_argument(
+            '--host',
+            action='store_true',
+            default=False,
+            help=_("Clear host binding for the port.")
+        )
 
         _tag.add_tag_option_to_parser_for_unset(parser, _('port'))
 
@@ -955,6 +1058,13 @@ class UnsetPort(command.Command):
             attrs['qos_policy_id'] = None
         if parsed_args.data_plane_status:
             attrs['data_plane_status'] = None
+        if parsed_args.numa_policy:
+            attrs['numa_affinity_policy'] = None
+        if parsed_args.host:
+            attrs['binding:host_id'] = None
+
+        attrs.update(
+            self._parse_extra_properties(parsed_args.extra_properties))
 
         if attrs:
             client.update_port(obj, **attrs)
