@@ -28,8 +28,6 @@ from osc_lib.utils import tags as _tag
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import common
-from openstackclient.network import sdk_utils
-
 
 LOG = logging.getLogger(__name__)
 
@@ -69,21 +67,20 @@ _formatters = {
 
 def _get_columns(item):
     column_map = {
-        'tenant_id': 'project_id',
         'is_ha': 'ha',
         'is_distributed': 'distributed',
         'is_admin_state_up': 'admin_state_up',
     }
     if hasattr(item, 'interfaces_info'):
         column_map['interfaces_info'] = 'interfaces_info'
-    invisible_columns = []
+    invisible_columns = ['location']
     if item.is_ha is None:
         invisible_columns.append('is_ha')
         column_map.pop('is_ha')
     if item.is_distributed is None:
         invisible_columns.append('is_distributed')
         column_map.pop('is_distributed')
-    return sdk_utils.get_osc_show_columns_for_sdk_resource(
+    return utils.get_osc_show_columns_for_sdk_resource(
         item, column_map, invisible_columns)
 
 
@@ -112,7 +109,31 @@ def _get_attrs(client_manager, parsed_args):
             parsed_args.project,
             parsed_args.project_domain,
         ).id
-        attrs['tenant_id'] = project_id
+        attrs['project_id'] = project_id
+    if parsed_args.external_gateway:
+        gateway_info = {}
+        n_client = client_manager.network
+        network = n_client.find_network(
+            parsed_args.external_gateway, ignore_missing=False)
+        gateway_info['network_id'] = network.id
+        if parsed_args.disable_snat:
+            gateway_info['enable_snat'] = False
+        if parsed_args.enable_snat:
+            gateway_info['enable_snat'] = True
+        if parsed_args.fixed_ip:
+            ips = []
+            for ip_spec in parsed_args.fixed_ip:
+                if ip_spec.get('subnet', False):
+                    subnet_name_id = ip_spec.pop('subnet')
+                    if subnet_name_id:
+                        subnet = n_client.find_subnet(subnet_name_id,
+                                                      ignore_missing=False)
+                        ip_spec['subnet_id'] = subnet.id
+                if ip_spec.get('ip-address', False):
+                    ip_spec['ip_address'] = ip_spec.pop('ip-address')
+                ips.append(ip_spec)
+            gateway_info['external_fixed_ips'] = ips
+        attrs['external_gateway_info'] = gateway_info
 
     return attrs
 
@@ -322,6 +343,47 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
                    "repeat option to set multiple availability zones)")
         )
         _tag.add_tag_option_to_parser_for_create(parser, _('router'))
+        parser.add_argument(
+            '--external-gateway',
+            metavar="<network>",
+            help=_("External Network used as router's gateway (name or ID)")
+        )
+        parser.add_argument(
+            '--fixed-ip',
+            metavar='subnet=<subnet>,ip-address=<ip-address>',
+            action=parseractions.MultiKeyValueAction,
+            optional_keys=['subnet', 'ip-address'],
+            help=_("Desired IP and/or subnet (name or ID) "
+                   "on external gateway: "
+                   "subnet=<subnet>,ip-address=<ip-address> "
+                   "(repeat option to set multiple fixed IP addresses)")
+        )
+        snat_group = parser.add_mutually_exclusive_group()
+        snat_group.add_argument(
+            '--enable-snat',
+            action='store_true',
+            help=_("Enable Source NAT on external gateway")
+        )
+        snat_group.add_argument(
+            '--disable-snat',
+            action='store_true',
+            help=_("Disable Source NAT on external gateway")
+        )
+        ndp_proxy_group = parser.add_mutually_exclusive_group()
+        ndp_proxy_group.add_argument(
+            '--enable-ndp-proxy',
+            dest='enable_ndp_proxy',
+            default=None,
+            action='store_true',
+            help=_("Enable IPv6 NDP proxy on external gateway")
+        )
+        ndp_proxy_group.add_argument(
+            '--disable-ndp-proxy',
+            dest='enable_ndp_proxy',
+            default=None,
+            action='store_false',
+            help=_("Disable IPv6 NDP proxy on external gateway")
+        )
 
         return parser
 
@@ -336,10 +398,24 @@ class CreateRouter(command.ShowOne, common.NeutronCommandWithExtraArgs):
         attrs.update(
             self._parse_extra_properties(parsed_args.extra_properties))
 
+        if parsed_args.enable_ndp_proxy and not parsed_args.external_gateway:
+            msg = (_("You must specify '--external-gateway' in order "
+                     "to enable router's NDP proxy"))
+            raise exceptions.CommandError(msg)
+
+        if parsed_args.enable_ndp_proxy is not None:
+            attrs['enable_ndp_proxy'] = parsed_args.enable_ndp_proxy
+
         obj = client.create_router(**attrs)
         # tags cannot be set when created, so tags need to be set later.
         _tag.update_tags_for_set(client, obj, parsed_args)
 
+        if (parsed_args.disable_snat or parsed_args.enable_snat or
+                parsed_args.fixed_ip) and not parsed_args.external_gateway:
+            msg = (_("You must specify '--external-gateway' in order "
+                     "to specify SNAT or fixed-ip values"))
+            raise exceptions.CommandError(msg)
+
         display_columns, columns = _get_columns(obj)
         data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
@@ -461,7 +537,6 @@ class ListRouter(command.Lister):
                 parsed_args.project,
                 parsed_args.project_domain,
             ).id
-            args['tenant_id'] = project_id
             args['project_id'] = project_id
 
         _tag.get_tag_filtering_args(parsed_args, args)
@@ -685,6 +760,21 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
             action='store_true',
             help=_("Disable Source NAT on external gateway")
         )
+        ndp_proxy_group = parser.add_mutually_exclusive_group()
+        ndp_proxy_group.add_argument(
+            '--enable-ndp-proxy',
+            dest='enable_ndp_proxy',
+            default=None,
+            action='store_true',
+            help=_("Enable IPv6 NDP proxy on external gateway")
+        )
+        ndp_proxy_group.add_argument(
+            '--disable-ndp-proxy',
+            dest='enable_ndp_proxy',
+            default=None,
+            action='store_false',
+            help=_("Disable IPv6 NDP proxy on external gateway")
+        )
         qos_policy_group = parser.add_mutually_exclusive_group()
         qos_policy_group.add_argument(
             '--qos-policy',
@@ -727,29 +817,6 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
             msg = (_("You must specify '--external-gateway' in order "
                      "to update the SNAT or fixed-ip values"))
             raise exceptions.CommandError(msg)
-        if parsed_args.external_gateway:
-            gateway_info = {}
-            network = client.find_network(
-                parsed_args.external_gateway, ignore_missing=False)
-            gateway_info['network_id'] = network.id
-            if parsed_args.disable_snat:
-                gateway_info['enable_snat'] = False
-            if parsed_args.enable_snat:
-                gateway_info['enable_snat'] = True
-            if parsed_args.fixed_ip:
-                ips = []
-                for ip_spec in parsed_args.fixed_ip:
-                    if ip_spec.get('subnet', False):
-                        subnet_name_id = ip_spec.pop('subnet')
-                        if subnet_name_id:
-                            subnet = client.find_subnet(subnet_name_id,
-                                                        ignore_missing=False)
-                            ip_spec['subnet_id'] = subnet.id
-                    if ip_spec.get('ip-address', False):
-                        ip_spec['ip_address'] = ip_spec.pop('ip-address')
-                    ips.append(ip_spec)
-                gateway_info['external_fixed_ips'] = ips
-            attrs['external_gateway_info'] = gateway_info
 
         if ((parsed_args.qos_policy or parsed_args.no_qos_policy) and
                 not parsed_args.external_gateway):
@@ -775,6 +842,9 @@ class SetRouter(common.NeutronCommandWithExtraArgs):
         attrs.update(
             self._parse_extra_properties(parsed_args.extra_properties))
 
+        if parsed_args.enable_ndp_proxy is not None:
+            attrs['enable_ndp_proxy'] = parsed_args.enable_ndp_proxy
+
         if attrs:
             client.update_router(obj, **attrs)
         # tags is a subresource and it needs to be updated separately.
