@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import json
 import random
 import uuid
 
@@ -24,78 +23,31 @@ class FloatingIpTests(common.NetworkTests):
     def setUpClass(cls):
         common.NetworkTests.setUpClass()
         if cls.haz_network:
+            # Create common networks that all tests share
             cls.EXTERNAL_NETWORK_NAME = uuid.uuid4().hex
-            cls.EXTERNAL_SUBNET_NAME = uuid.uuid4().hex
             cls.PRIVATE_NETWORK_NAME = uuid.uuid4().hex
-            cls.PRIVATE_SUBNET_NAME = uuid.uuid4().hex
-            cls.ROUTER = uuid.uuid4().hex
-            cls.PORT_NAME = uuid.uuid4().hex
 
             # Create a network for the floating ip
-            json_output = json.loads(cls.openstack(
-                'network create -f json ' +
+            json_output = cls.openstack(
+                'network create ' +
                 '--external ' +
-                cls.EXTERNAL_NETWORK_NAME
-            ))
+                cls.EXTERNAL_NETWORK_NAME,
+                parse_output=True,
+            )
             cls.external_network_id = json_output["id"]
 
             # Create a private network for the port
-            json_output = json.loads(cls.openstack(
-                'network create -f json ' +
-                cls.PRIVATE_NETWORK_NAME
-            ))
+            json_output = cls.openstack(
+                'network create ' +
+                cls.PRIVATE_NETWORK_NAME,
+                parse_output=True,
+            )
             cls.private_network_id = json_output["id"]
 
-            # Try random subnet range for subnet creating
-            # Because we can not determine ahead of time what subnets are
-            # already in use, possibly by another test running in parallel,
-            # try 4 times
-            for i in range(4):
-                # Make a random subnet
-                cls.external_subnet = ".".join(map(
-                    str,
-                    (random.randint(0, 223) for _ in range(3))
-                )) + ".0/26"
-                cls.private_subnet = ".".join(map(
-                    str,
-                    (random.randint(0, 223) for _ in range(3))
-                )) + ".0/26"
-                try:
-                    # Create a subnet for the network
-                    json_output = json.loads(cls.openstack(
-                        'subnet create -f json ' +
-                        '--network ' + cls.EXTERNAL_NETWORK_NAME + ' ' +
-                        '--subnet-range ' + cls.external_subnet + ' ' +
-                        cls.EXTERNAL_SUBNET_NAME
-                    ))
-                    cls.external_subnet_id = json_output["id"]
-                    # Create a subnet for the private network
-                    json_output = json.loads(cls.openstack(
-                        'subnet create -f json ' +
-                        '--network ' + cls.PRIVATE_NETWORK_NAME + ' ' +
-                        '--subnet-range ' + cls.private_subnet + ' ' +
-                        cls.PRIVATE_SUBNET_NAME
-                    ))
-                    cls.private_subnet_id = json_output["id"]
-                except Exception:
-                    if (i == 3):
-                        # raise the exception at the last time
-                        raise
-                    pass
-                else:
-                    # break and no longer retry if create successfully
-                    break
-
     @classmethod
     def tearDownClass(cls):
         try:
             if cls.haz_network:
-                del_output = cls.openstack(
-                    'subnet delete ' +
-                    cls.EXTERNAL_SUBNET_NAME + ' ' +
-                    cls.PRIVATE_SUBNET_NAME
-                )
-                cls.assertOutput('', del_output)
                 del_output = cls.openstack(
                     'network delete ' +
                     cls.EXTERNAL_NETWORK_NAME + ' ' +
@@ -114,16 +66,57 @@ class FloatingIpTests(common.NetworkTests):
         # Verify setup
         self.assertIsNotNone(self.external_network_id)
         self.assertIsNotNone(self.private_network_id)
-        self.assertIsNotNone(self.external_subnet_id)
-        self.assertIsNotNone(self.private_subnet_id)
+
+    def _create_subnet(self, network_name, subnet_name):
+        subnet_id = None
+
+        # Try random subnet range for subnet creating
+        # Because we can not determine ahead of time what subnets are
+        # already in use, possibly by another test running in parallel,
+        # try 4 times
+        for i in range(4):
+            # Make a random subnet
+            subnet = ".".join(map(
+                str,
+                (random.randint(0, 223) for _ in range(3))
+            )) + ".0/26"
+            try:
+                # Create a subnet for the network
+                json_output = self.openstack(
+                    'subnet create ' +
+                    '--network ' + network_name + ' ' +
+                    '--subnet-range ' + subnet + ' ' +
+                    subnet_name,
+                    parse_output=True,
+                )
+                self.assertIsNotNone(json_output["id"])
+                subnet_id = json_output["id"]
+            except Exception:
+                if (i == 3):
+                    # raise the exception at the last time
+                    raise
+                pass
+            else:
+                # break and no longer retry if create successfully
+                break
+        return subnet_id
 
     def test_floating_ip_delete(self):
         """Test create, delete multiple"""
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
+
+        # Subnets must exist even if not directly referenced here
+        ext_subnet_id = self._create_subnet(
+            self.EXTERNAL_NETWORK_NAME,
+            "ext-test-delete"
+        )
+        self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
+
+        json_output = self.openstack(
+            'floating ip create ' +
             '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+            self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.assertEqual(
@@ -131,11 +124,12 @@ class FloatingIpTests(common.NetworkTests):
             json_output["description"],
         )
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
+        json_output = self.openstack(
+            'floating ip create ' +
             '--description bbbb ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+            self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip2 = json_output["id"]
         self.assertEqual(
@@ -151,11 +145,20 @@ class FloatingIpTests(common.NetworkTests):
 
     def test_floating_ip_list(self):
         """Test create defaults, list filters, delete"""
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
+
+        # Subnets must exist even if not directly referenced here
+        ext_subnet_id = self._create_subnet(
+            self.EXTERNAL_NETWORK_NAME,
+            "ext-test-delete"
+        )
+        self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
+
+        json_output = self.openstack(
+            'floating ip create ' +
             '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+            self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip1)
@@ -166,11 +169,12 @@ class FloatingIpTests(common.NetworkTests):
         self.assertIsNotNone(json_output["floating_network_id"])
         fip1 = json_output["floating_ip_address"]
 
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
+        json_output = self.openstack(
+            'floating ip create ' +
             '--description bbbb ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+            self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip2 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip2)
@@ -182,9 +186,10 @@ class FloatingIpTests(common.NetworkTests):
         fip2 = json_output["floating_ip_address"]
 
         # Test list
-        json_output = json.loads(self.openstack(
-            'floating ip list -f json'
-        ))
+        json_output = self.openstack(
+            'floating ip list',
+            parse_output=True,
+        )
         fip_map = {
             item.get('ID'):
                 item.get('Floating IP Address') for item in json_output
@@ -196,10 +201,11 @@ class FloatingIpTests(common.NetworkTests):
         self.assertIn(fip2, fip_map.values())
 
         # Test list --long
-        json_output = json.loads(self.openstack(
-            'floating ip list -f json ' +
-            '--long'
-        ))
+        json_output = self.openstack(
+            'floating ip list ' +
+            '--long',
+            parse_output=True,
+        )
         fip_map = {
             item.get('ID'):
                 item.get('Floating IP Address') for item in json_output
@@ -216,10 +222,11 @@ class FloatingIpTests(common.NetworkTests):
 
         # TODO(dtroyer): add more filter tests
 
-        json_output = json.loads(self.openstack(
-            'floating ip show -f json ' +
-            ip1
-        ))
+        json_output = self.openstack(
+            'floating ip show ' +
+            ip1,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         self.assertEqual(
             ip1,
@@ -237,11 +244,28 @@ class FloatingIpTests(common.NetworkTests):
 
     def test_floating_ip_set_and_unset_port(self):
         """Test Floating IP Set and Unset port"""
-        json_output = json.loads(self.openstack(
-            'floating ip create -f json ' +
+
+        # Subnets must exist even if not directly referenced here
+        ext_subnet_id = self._create_subnet(
+            self.EXTERNAL_NETWORK_NAME,
+            "ext-test-delete"
+        )
+        self.addCleanup(self.openstack, 'subnet delete ' + ext_subnet_id)
+        priv_subnet_id = self._create_subnet(
+            self.PRIVATE_NETWORK_NAME,
+            "priv-test-delete"
+        )
+        self.addCleanup(self.openstack, 'subnet delete ' + priv_subnet_id)
+
+        self.ROUTER = uuid.uuid4().hex
+        self.PORT_NAME = uuid.uuid4().hex
+
+        json_output = self.openstack(
+            'floating ip create ' +
             '--description aaaa ' +
-            self.EXTERNAL_NETWORK_NAME
-        ))
+            self.EXTERNAL_NETWORK_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         ip1 = json_output["id"]
         self.addCleanup(self.openstack, 'floating ip delete ' + ip1)
@@ -250,19 +274,21 @@ class FloatingIpTests(common.NetworkTests):
             json_output["description"],
         )
 
-        json_output = json.loads(self.openstack(
-            'port create -f json ' +
+        json_output = self.openstack(
+            'port create ' +
             '--network ' + self.PRIVATE_NETWORK_NAME + ' ' +
-            '--fixed-ip subnet=' + self.PRIVATE_SUBNET_NAME + ' ' +
-            self.PORT_NAME
-        ))
+            '--fixed-ip subnet=' + priv_subnet_id + ' ' +
+            self.PORT_NAME,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         port_id = json_output["id"]
 
-        json_output = json.loads(self.openstack(
-            'router create -f json ' +
-            self.ROUTER
-        ))
+        json_output = self.openstack(
+            'router create ' +
+            self.ROUTER,
+            parse_output=True,
+        )
         self.assertIsNotNone(json_output["id"])
         self.addCleanup(self.openstack, 'router delete ' + self.ROUTER)
 
@@ -296,10 +322,11 @@ class FloatingIpTests(common.NetworkTests):
             'floating ip unset --port ' + ip1,
         )
 
-        json_output = json.loads(self.openstack(
-            'floating ip show -f json ' +
-            ip1
-        ))
+        json_output = self.openstack(
+            'floating ip show ' +
+            ip1,
+            parse_output=True,
+        )
 
         self.assertEqual(
             port_id,
