@@ -14,20 +14,26 @@ import os
 import tempfile
 import uuid
 
-from openstackclient.tests.functional import base
+from openstackclient.tests.functional.object.v1 import common
 
 BASIC_LIST_HEADERS = ['Name']
 CONTAINER_FIELDS = ['account', 'container', 'x-trans-id']
 OBJECT_FIELDS = ['object', 'container', 'etag']
 
 
-class ObjectTests(base.TestCase):
-    """Functional tests for Object commands. """
+class ObjectTests(common.ObjectStoreTests):
+    """Functional tests for Object Store object commands"""
 
     CONTAINER_NAME = uuid.uuid4().hex
 
+    def setUp(self):
+        super(ObjectTests, self).setUp()
+        # Skip tests if no object-store is present
+        if not self.haz_object_store:
+            self.skipTest("No object-store service present")
+
     def test_object(self):
-        with tempfile.NamedTemporaryFile() as f:
+        with tempfile.NamedTemporaryFile(mode='w+') as f:
             f.write('test content')
             f.flush()
             self._test_object(f.name)
@@ -47,39 +53,39 @@ class ObjectTests(base.TestCase):
         self.openstack('container save ' + self.CONTAINER_NAME)
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object create ' + self.CONTAINER_NAME
-                                    + ' ' + object_file)
+        raw_output = self.openstack('object create %s %s' %
+                                    (self.CONTAINER_NAME, object_file))
         items = self.parse_listing(raw_output)
         self.assert_show_fields(items, OBJECT_FIELDS)
 
-        raw_output = self.openstack('object list ' + self.CONTAINER_NAME)
+        raw_output = self.openstack('object list %s' % self.CONTAINER_NAME)
         items = self.parse_listing(raw_output)
         self.assert_table_structure(items, BASIC_LIST_HEADERS)
 
-        self.openstack('object save ' + self.CONTAINER_NAME
-                       + ' ' + object_file)
+        self.openstack('object save %s %s' %
+                       (self.CONTAINER_NAME, object_file))
         # TODO(stevemar): Assert returned fields
 
         tmp_file = 'tmp.txt'
         self.addCleanup(os.remove, tmp_file)
-        self.openstack('object save ' + self.CONTAINER_NAME
-                       + ' ' + object_file + ' --file ' + tmp_file)
+        self.openstack('object save %s %s --file %s' %
+                       (self.CONTAINER_NAME, object_file, tmp_file))
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object save ' + self.CONTAINER_NAME
-                                    + ' ' + object_file + ' --file -')
+        raw_output = self.openstack('object save %s %s --file -' %
+                                    (self.CONTAINER_NAME, object_file))
         self.assertEqual(raw_output, 'test content')
 
-        self.openstack('object show ' + self.CONTAINER_NAME
-                       + ' ' + object_file)
+        self.openstack('object show %s %s' %
+                       (self.CONTAINER_NAME, object_file))
         # TODO(stevemar): Assert returned fields
 
-        raw_output = self.openstack('object delete ' + self.CONTAINER_NAME
-                                    + ' ' + object_file)
+        raw_output = self.openstack('object delete %s %s' %
+                                    (self.CONTAINER_NAME, object_file))
         self.assertEqual(0, len(raw_output))
 
-        self.openstack('object create ' + self.CONTAINER_NAME
-                       + ' ' + object_file)
-        raw_output = self.openstack('container delete -r ' +
+        self.openstack('object create %s %s' %
+                       (self.CONTAINER_NAME, object_file))
+        raw_output = self.openstack('container delete -r %s' %
                                     self.CONTAINER_NAME)
         self.assertEqual(0, len(raw_output))
