@@ -62,6 +62,9 @@ class TestQuota(compute_fakes.TestComputev2):
             self.app.client_manager.volume.quota_classes
         self.volume_quotas_class_mock.reset_mock()
 
+        self.app.client_manager.network = mock.Mock()
+        self.network_mock = self.app.client_manager.network
+
         self.app.client_manager.auth_ref = mock.Mock()
         self.app.client_manager.auth_ref.service_catalog = mock.Mock()
         self.service_catalog_mock = \
@@ -173,12 +176,12 @@ class TestQuotaList(TestQuota):
         )
 
         self.volume_quotas = [
-            volume_fakes.FakeQuota.create_one_vol_quota(),
-            volume_fakes.FakeQuota.create_one_vol_quota(),
+            volume_fakes.create_one_vol_quota(),
+            volume_fakes.create_one_vol_quota(),
         ]
         self.volume_default_quotas = [
-            volume_fakes.FakeQuota.create_one_default_vol_quota(),
-            volume_fakes.FakeQuota.create_one_default_vol_quota(),
+            volume_fakes.create_one_default_vol_quota(),
+            volume_fakes.create_one_default_vol_quota(),
         ]
         self.volume = self.app.client_manager.volume
         self.volume.quotas.defaults = mock.Mock(
@@ -276,6 +279,36 @@ class TestQuotaList(TestQuota):
         self.assertEqual(
             sorted(detailed_reference_data), sorted(ret_quotas))
 
+    def test_quota_list_details_volume(self):
+        detailed_quota = volume_fakes.create_one_detailed_quota()
+
+        detailed_column_header = (
+            'Resource',
+            'In Use',
+            'Reserved',
+            'Limit',
+        )
+        detailed_reference_data = (
+            self._get_detailed_reference_data(detailed_quota))
+
+        self.volume.quotas.get = mock.Mock(return_value=detailed_quota)
+
+        arglist = [
+            '--detail',
+            '--volume',
+        ]
+        verifylist = [
+            ('detail', True),
+            ('volume', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        ret_quotas = list(data)
+
+        self.assertEqual(detailed_column_header, columns)
+        self.assertEqual(sorted(detailed_reference_data), sorted(ret_quotas))
+
     def test_quota_list_compute(self):
         # Two projects with non-default quotas
         self.compute.quotas.get = mock.Mock(
@@ -533,7 +566,7 @@ class TestQuotaList(TestQuota):
         self.volume.quotas.get = mock.Mock(
             side_effect=[
                 self.volume_quotas[0],
-                volume_fakes.FakeQuota.create_one_default_vol_quota(),
+                volume_fakes.create_one_default_vol_quota(),
             ],
         )
 
@@ -557,7 +590,7 @@ class TestQuotaList(TestQuota):
         self.volume.quotas.get = mock.Mock(
             side_effect=[
                 self.volume_quotas[0],
-                volume_fakes.FakeQuota.create_one_default_vol_quota(),
+                volume_fakes.create_one_default_vol_quota(),
             ],
         )
 
@@ -627,7 +660,6 @@ class TestQuotaSet(TestQuota):
             loaded=True,
         )
 
-        self.network_mock = self.app.client_manager.network
         self.network_mock.update_quota = mock.Mock()
 
         self.cmd = quota.SetQuota(self.app, None)
@@ -951,19 +983,19 @@ class TestQuotaSet(TestQuota):
         )
         self.assertIsNone(result)
 
-    def test_quota_set_with_check_limit(self):
+    def test_quota_set_with_no_force(self):
         arglist = [
             '--subnets', str(network_fakes.QUOTA['subnet']),
             '--volumes', str(volume_fakes.QUOTA['volumes']),
             '--cores', str(compute_fakes.core_num),
-            '--check-limit',
+            '--no-force',
             self.projects[0].name,
         ]
         verifylist = [
             ('subnet', network_fakes.QUOTA['subnet']),
             ('volumes', volume_fakes.QUOTA['volumes']),
             ('cores', compute_fakes.core_num),
-            ('check_limit', True),
+            ('force', False),
             ('project', self.projects[0].name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -972,6 +1004,7 @@ class TestQuotaSet(TestQuota):
 
         kwargs_compute = {
             'cores': compute_fakes.core_num,
+            'force': False,
         }
         kwargs_volume = {
             'volumes': volume_fakes.QUOTA['volumes'],
@@ -998,7 +1031,7 @@ class TestQuotaSet(TestQuota):
 class TestQuotaShow(TestQuota):
 
     def setUp(self):
-        super(TestQuotaShow, self).setUp()
+        super().setUp()
 
         self.compute_quota = compute_fakes.FakeQuota.create_one_comp_quota()
         self.compute_quotas_mock.get.return_value = self.compute_quota
@@ -1012,10 +1045,9 @@ class TestQuotaShow(TestQuota):
             loaded=True,
         )
 
-        self.volume_quota = volume_fakes.FakeQuota.create_one_vol_quota()
+        self.volume_quota = volume_fakes.create_one_vol_quota()
         self.volume_quotas_mock.get.return_value = self.volume_quota
-        self.volume_default_quota = \
-            volume_fakes.FakeQuota.create_one_default_vol_quota()
+        self.volume_default_quota = volume_fakes.create_one_default_vol_quota()
         self.volume_quotas_mock.defaults.return_value = \
             self.volume_default_quota
         self.volume_quotas_class_mock.get.return_value = FakeQuotaResource(
@@ -1053,6 +1085,7 @@ class TestQuotaShow(TestQuota):
             self.projects[0].name,
         ]
         verifylist = [
+            ('service', 'all'),
             ('project', self.projects[0].name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -1060,17 +1093,81 @@ class TestQuotaShow(TestQuota):
         self.cmd.take_action(parsed_args)
 
         self.compute_quotas_mock.get.assert_called_once_with(
-            self.projects[0].id, detail=False
+            self.projects[0].id,
+            detail=False,
         )
         self.volume_quotas_mock.get.assert_called_once_with(
             self.projects[0].id,
+            usage=False,
         )
         self.network.get_quota.assert_called_once_with(
-            self.projects[0].id, details=False
+            self.projects[0].id,
+            details=False,
         )
         self.assertNotCalled(self.network.get_quota_default)
 
-    def test_quota_show_with_default(self):
+    def test_quota_show__with_compute(self):
+        arglist = [
+            '--compute',
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('service', 'compute'),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.compute_quotas_mock.get.assert_called_once_with(
+            self.projects[0].id,
+            detail=False,
+        )
+        self.volume_quotas_mock.get.assert_not_called()
+        self.network.get_quota.assert_not_called()
+
+    def test_quota_show__with_volume(self):
+        arglist = [
+            '--volume',
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('service', 'volume'),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.compute_quotas_mock.get.assert_not_called()
+        self.volume_quotas_mock.get.assert_called_once_with(
+            self.projects[0].id,
+            usage=False,
+        )
+        self.network.get_quota.assert_not_called()
+
+    def test_quota_show__with_network(self):
+        arglist = [
+            '--network',
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('service', 'network'),
+            ('project', self.projects[0].name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.compute_quotas_mock.get.assert_not_called()
+        self.volume_quotas_mock.get.assert_not_called()
+        self.network.get_quota.assert_called_once_with(
+            self.projects[0].id,
+            details=False,
+        )
+        self.assertNotCalled(self.network.get_quota_default)
+
+    def test_quota_show__with_default(self):
         arglist = [
             '--default',
             self.projects[0].name,
@@ -1094,30 +1191,66 @@ class TestQuotaShow(TestQuota):
         )
         self.assertNotCalled(self.network.get_quota)
 
-    def test_quota_show_with_class(self):
+    def test_quota_show__with_class(self):
         arglist = [
             '--class',
-            self.projects[0].name,
+            'default',
         ]
         verifylist = [
             ('quota_class', True),
+            ('project', 'default'),  # project is actually a class here
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.cmd.take_action(parsed_args)
+
+        self.compute_quotas_class_mock.get.assert_called_once_with('default')
+        self.volume_quotas_class_mock.get.assert_called_once_with('default')
+        # neutron doesn't have the concept of quota classes
+        self.assertNotCalled(self.network.get_quota)
+        self.assertNotCalled(self.network.get_quota_default)
+
+    def test_quota_show__with_usage(self):
+        # update mocks to return detailed quota instead
+        self.compute_quota = \
+            compute_fakes.FakeQuota.create_one_comp_detailed_quota()
+        self.compute_quotas_mock.get.return_value = self.compute_quota
+        self.volume_quota = volume_fakes.create_one_detailed_quota()
+        self.volume_quotas_mock.get.return_value = self.volume_quota
+        self.network.get_quota.return_value = \
+            network_fakes.FakeQuota.create_one_net_detailed_quota()
+
+        arglist = [
+            '--usage',
+            self.projects[0].name,
+        ]
+        verifylist = [
+            ('usage', True),
             ('project', self.projects[0].name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
 
-        self.compute_quotas_class_mock.get.assert_called_once_with(
-            self.projects[0].name,
+        self.compute_quotas_mock.get.assert_called_once_with(
+            self.projects[0].id,
+            detail=True,
         )
-        self.volume_quotas_class_mock.get.assert_called_once_with(
-            self.projects[0].name,
+        self.volume_quotas_mock.get.assert_called_once_with(
+            self.projects[0].id,
+            usage=True,
+        )
+        self.network.get_quota.assert_called_once_with(
+            self.projects[0].id,
+            details=True,
         )
-        self.assertNotCalled(self.network.get_quota)
-        self.assertNotCalled(self.network.get_quota_default)
 
-    def test_quota_show_no_project(self):
-        parsed_args = self.check_parser(self.cmd, [], [])
+    def test_quota_show__no_project(self):
+        arglist = []
+        verifylist = [
+            ('project', None),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         self.cmd.take_action(parsed_args)
 
@@ -1125,32 +1258,115 @@ class TestQuotaShow(TestQuota):
             identity_fakes.project_id, detail=False
         )
         self.volume_quotas_mock.get.assert_called_once_with(
-            identity_fakes.project_id,
+            identity_fakes.project_id, usage=False
         )
         self.network.get_quota.assert_called_once_with(
             identity_fakes.project_id, details=False
         )
         self.assertNotCalled(self.network.get_quota_default)
 
-    def test_network_quota_show_remove_empty(self):
+
+class TestQuotaDelete(TestQuota):
+    """Test cases for quota delete command"""
+
+    def setUp(self):
+        super().setUp()
+
+        self.network_mock.delete_quota = mock.Mock()
+
+        self.cmd = quota.DeleteQuota(self.app, None)
+
+    def test_delete(self):
+        """Delete all quotas"""
         arglist = [
-            self.projects[0].name,
+            self.projects[0].id,
         ]
         verifylist = [
-            ('project', self.projects[0].name),
+            ('service', 'all'),
+            ('project', self.projects[0].id),
         ]
+
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        # First check that all regular values are returned
-        result = self.cmd.get_network_quota(parsed_args)
-        self.assertEqual(len(network_fakes.QUOTA), len(result))
+        result = self.cmd.take_action(parsed_args)
 
-        # set 1 of the values to None, and verify it is not returned
-        orig_get_quota = self.network.get_quota
-        network_quotas = copy.copy(network_fakes.QUOTA)
-        network_quotas['healthmonitor'] = None
-        self.network.get_quota = mock.Mock(return_value=network_quotas)
-        result = self.cmd.get_network_quota(parsed_args)
-        self.assertEqual(len(network_fakes.QUOTA) - 1, len(result))
-        # Go back to default mock
-        self.network.get_quota = orig_get_quota
+        self.assertIsNone(result)
+        self.projects_mock.get.assert_called_once_with(self.projects[0].id)
+        self.compute_quotas_mock.delete.assert_called_once_with(
+            self.projects[0].id,
+        )
+        self.volume_quotas_mock.delete.assert_called_once_with(
+            self.projects[0].id,
+        )
+        self.network_mock.delete_quota.assert_called_once_with(
+            self.projects[0].id,
+        )
+
+    def test_delete__compute(self):
+        """Delete compute quotas only"""
+        arglist = [
+            '--compute',
+            self.projects[0].id,
+        ]
+        verifylist = [
+            ('service', 'compute'),
+            ('project', self.projects[0].id),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.assertIsNone(result)
+        self.projects_mock.get.assert_called_once_with(self.projects[0].id)
+        self.compute_quotas_mock.delete.assert_called_once_with(
+            self.projects[0].id,
+        )
+        self.volume_quotas_mock.delete.assert_not_called()
+        self.network_mock.delete_quota.assert_not_called()
+
+    def test_delete__volume(self):
+        """Delete volume quotas only"""
+        arglist = [
+            '--volume',
+            self.projects[0].id,
+        ]
+        verifylist = [
+            ('service', 'volume'),
+            ('project', self.projects[0].id),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.assertIsNone(result)
+        self.projects_mock.get.assert_called_once_with(self.projects[0].id)
+        self.compute_quotas_mock.delete.assert_not_called()
+        self.volume_quotas_mock.delete.assert_called_once_with(
+            self.projects[0].id,
+        )
+        self.network_mock.delete_quota.assert_not_called()
+
+    def test_delete__network(self):
+        """Delete network quotas only"""
+        arglist = [
+            '--network',
+            self.projects[0].id,
+        ]
+        verifylist = [
+            ('service', 'network'),
+            ('project', self.projects[0].id),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        self.assertIsNone(result)
+        self.projects_mock.get.assert_called_once_with(self.projects[0].id)
+        self.compute_quotas_mock.delete.assert_not_called()
+        self.volume_quotas_mock.delete.assert_not_called()
+        self.network_mock.delete_quota.assert_called_once_with(
+            self.projects[0].id,
+        )
