@@ -20,7 +20,14 @@ import uuid
 
 from novaclient import api_versions
 from openstack.compute.v2 import flavor as _flavor
-from openstack.compute.v2 import server
+from openstack.compute.v2 import hypervisor as _hypervisor
+from openstack.compute.v2 import migration as _migration
+from openstack.compute.v2 import server as _server
+from openstack.compute.v2 import server_group as _server_group
+from openstack.compute.v2 import server_interface as _server_interface
+from openstack.compute.v2 import server_migration as _server_migration
+from openstack.compute.v2 import service
+from openstack.compute.v2 import volume_attachment
 
 from openstackclient.api import compute_v2
 from openstackclient.tests.unit import fakes
@@ -336,136 +343,6 @@ class FakeExtension(object):
         return extension
 
 
-class FakeHypervisor(object):
-    """Fake one or more hypervisor."""
-
-    @staticmethod
-    def create_one_hypervisor(attrs=None):
-        """Create a fake hypervisor.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id, hypervisor_hostname, and so on
-        """
-        attrs = attrs or {}
-
-        # Set default attributes.
-        hypervisor_info = {
-            'id': 'hypervisor-id-' + uuid.uuid4().hex,
-            'hypervisor_hostname': 'hypervisor-hostname-' + uuid.uuid4().hex,
-            'status': 'enabled',
-            'host_ip': '192.168.0.10',
-            'cpu_info': {
-                'aaa': 'aaa',
-            },
-            'free_disk_gb': 50,
-            'hypervisor_version': 2004001,
-            'disk_available_least': 50,
-            'local_gb': 50,
-            'free_ram_mb': 1024,
-            'service': {
-                'host': 'aaa',
-                'disabled_reason': None,
-                'id': 1,
-            },
-            'vcpus_used': 0,
-            'hypervisor_type': 'QEMU',
-            'local_gb_used': 0,
-            'vcpus': 4,
-            'memory_mb_used': 512,
-            'memory_mb': 1024,
-            'current_workload': 0,
-            'state': 'up',
-            'running_vms': 0,
-        }
-
-        # Overwrite default attributes.
-        hypervisor_info.update(attrs)
-
-        hypervisor = fakes.FakeResource(info=copy.deepcopy(hypervisor_info),
-                                        loaded=True)
-        return hypervisor
-
-    @staticmethod
-    def create_hypervisors(attrs=None, count=2):
-        """Create multiple fake hypervisors.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :param int count:
-            The number of hypervisors to fake
-        :return:
-            A list of FakeResource objects faking the hypervisors
-        """
-        hypervisors = []
-        for i in range(0, count):
-            hypervisors.append(FakeHypervisor.create_one_hypervisor(attrs))
-
-        return hypervisors
-
-
-class FakeHypervisorStats(object):
-    """Fake one or more hypervisor stats."""
-
-    @staticmethod
-    def create_one_hypervisor_stats(attrs=None):
-        """Create a fake hypervisor stats.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with count, current_workload, and so on
-        """
-        attrs = attrs or {}
-
-        # Set default attributes.
-        stats_info = {
-            'count': 2,
-            'current_workload': 0,
-            'disk_available_least': 50,
-            'free_disk_gb': 100,
-            'free_ram_mb': 23000,
-            'local_gb': 100,
-            'local_gb_used': 0,
-            'memory_mb': 23800,
-            'memory_mb_used': 1400,
-            'running_vms': 3,
-            'vcpus': 8,
-            'vcpus_used': 3,
-        }
-
-        # Overwrite default attributes.
-        stats_info.update(attrs)
-
-        # Set default method.
-        hypervisor_stats_method = {'to_dict': stats_info}
-
-        hypervisor_stats = fakes.FakeResource(
-            info=copy.deepcopy(stats_info),
-            methods=copy.deepcopy(hypervisor_stats_method),
-            loaded=True)
-        return hypervisor_stats
-
-    @staticmethod
-    def create_hypervisors_stats(attrs=None, count=2):
-        """Create multiple fake hypervisors stats.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :param int count:
-            The number of hypervisors to fake
-        :return:
-            A list of FakeResource objects faking the hypervisors
-        """
-        hypervisors = []
-        for i in range(0, count):
-            hypervisors.append(
-                FakeHypervisorStats.create_one_hypervisor_stats(attrs))
-
-        return hypervisors
-
-
 class FakeSecurityGroup(object):
     """Fake one or more security groups."""
 
@@ -669,7 +546,12 @@ class FakeServer(object):
 
         # Overwrite default attributes.
         server_info.update(attrs)
-        return server.Server(**server_info)
+        server = _server.Server(**server_info)
+
+        # Override methods
+        server.trigger_crash_dump = mock.MagicMock()
+
+        return server
 
     @staticmethod
     def create_sdk_servers(attrs=None, methods=None, count=2):
@@ -762,7 +644,7 @@ class FakeService(object):
         :param dict attrs:
             A dictionary with all attributes
         :return:
-            A FakeResource object, with id, host, binary, and so on
+            A fake Service object, with id, host, binary, and so on
         """
         attrs = attrs or {}
 
@@ -772,21 +654,18 @@ class FakeService(object):
             'host': 'host-' + uuid.uuid4().hex,
             'binary': 'binary-' + uuid.uuid4().hex,
             'status': 'enabled',
-            'zone': 'zone-' + uuid.uuid4().hex,
+            'availability_zone': 'zone-' + uuid.uuid4().hex,
             'state': 'state-' + uuid.uuid4().hex,
             'updated_at': 'time-' + uuid.uuid4().hex,
             'disabled_reason': 'earthquake',
             # Introduced in API microversion 2.11
-            'forced_down': False,
+            'is_forced_down': False,
         }
 
         # Overwrite default attributes.
         service_info.update(attrs)
 
-        service = fakes.FakeResource(info=copy.deepcopy(service_info),
-                                     loaded=True)
-
-        return service
+        return service.Service(**service_info)
 
     @staticmethod
     def create_services(attrs=None, count=2):
@@ -1290,72 +1169,6 @@ class FakeHost(object):
         return host_info
 
 
-class FakeServerGroup(object):
-    """Fake one server group"""
-
-    @staticmethod
-    def _create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-
-        # Set default attributes.
-        server_group_info = {
-            'id': 'server-group-id-' + uuid.uuid4().hex,
-            'members': [],
-            'metadata': {},
-            'name': 'server-group-name-' + uuid.uuid4().hex,
-            'project_id': 'server-group-project-id-' + uuid.uuid4().hex,
-            'user_id': 'server-group-user-id-' + uuid.uuid4().hex,
-        }
-
-        # Overwrite default attributes.
-        server_group_info.update(attrs)
-
-        server_group = fakes.FakeResource(
-            info=copy.deepcopy(server_group_info),
-            loaded=True)
-        return server_group
-
-    @staticmethod
-    def create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-        attrs.setdefault('policies', ['policy1', 'policy2'])
-        return FakeServerGroup._create_one_server_group(attrs)
-
-
-class FakeServerGroupV264(object):
-    """Fake one server group fo API >= 2.64"""
-
-    @staticmethod
-    def create_one_server_group(attrs=None):
-        """Create a fake server group
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :return:
-            A FakeResource object, with id and other attributes
-        """
-        if attrs is None:
-            attrs = {}
-        attrs.setdefault('policy', 'policy1')
-        return FakeServerGroup._create_one_server_group(attrs)
-
-
 class FakeUsage(object):
     """Fake one or more usage."""
 
@@ -1454,7 +1267,7 @@ class FakeQuota(object):
 
     @staticmethod
     def create_one_default_comp_quota(attrs=None):
-        """Crate one quota"""
+        """Create one quota"""
 
         attrs = attrs or {}
 
@@ -1622,184 +1435,271 @@ class FakeRateLimit(object):
         self.next_available = next_available
 
 
-class FakeMigration(object):
-    """Fake one or more migrations."""
+def create_one_migration(attrs=None):
+    """Create a fake migration.
 
-    @staticmethod
-    def create_one_migration(attrs=None, methods=None):
-        """Create a fake migration.
+    :param dict attrs: A dictionary with all attributes
+    :return: A fake openstack.compute.v2.migration.Migration object
+    """
+    attrs = attrs or {}
 
-        :param dict attrs:
-            A dictionary with all attributes
-        :param dict methods:
-            A dictionary with all methods
-        :return:
-            A FakeResource object, with id, type, and so on
-        """
-        attrs = attrs or {}
-        methods = methods or {}
+    # Set default attributes.
+    migration_info = {
+        "created_at": "2017-01-31T08:03:21.000000",
+        "dest_compute": "compute-" + uuid.uuid4().hex,
+        "dest_host": "10.0.2.15",
+        "dest_node": "node-" + uuid.uuid4().hex,
+        "id": random.randint(1, 999),
+        "migration_type": "migration",
+        "new_flavor_id": uuid.uuid4().hex,
+        "old_flavor_id": uuid.uuid4().hex,
+        "project_id": uuid.uuid4().hex,
+        "server_id": uuid.uuid4().hex,
+        "source_compute": "compute-" + uuid.uuid4().hex,
+        "source_node": "node-" + uuid.uuid4().hex,
+        "status": "migrating",
+        "updated_at": "2017-01-31T08:03:25.000000",
+        "user_id": uuid.uuid4().hex,
+        "uuid": uuid.uuid4().hex,
+    }
 
-        # Set default attributes.
-        migration_info = {
-            "dest_host": "10.0.2.15",
-            "status": "migrating",
-            "migration_type": "migration",
-            "updated_at": "2017-01-31T08:03:25.000000",
-            "created_at": "2017-01-31T08:03:21.000000",
-            "dest_compute": "compute-" + uuid.uuid4().hex,
-            "id": random.randint(1, 999),
-            "source_node": "node-" + uuid.uuid4().hex,
-            "instance_uuid": uuid.uuid4().hex,
-            "dest_node": "node-" + uuid.uuid4().hex,
-            "source_compute": "compute-" + uuid.uuid4().hex,
-            "uuid": uuid.uuid4().hex,
-            "old_instance_type_id": uuid.uuid4().hex,
-            "new_instance_type_id": uuid.uuid4().hex,
-            "project_id": uuid.uuid4().hex,
-            "user_id": uuid.uuid4().hex
-        }
+    # Overwrite default attributes.
+    migration_info.update(attrs)
 
-        # Overwrite default attributes.
-        migration_info.update(attrs)
-
-        migration = fakes.FakeResource(info=copy.deepcopy(migration_info),
-                                       methods=methods,
-                                       loaded=True)
-        return migration
-
-    @staticmethod
-    def create_migrations(attrs=None, methods=None, count=2):
-        """Create multiple fake migrations.
-
-        :param dict attrs:
-            A dictionary with all attributes
-        :param dict methods:
-            A dictionary with all methods
-        :param int count:
-            The number of migrations to fake
-        :return:
-            A list of FakeResource objects faking the migrations
-        """
-        migrations = []
-        for i in range(0, count):
-            migrations.append(
-                FakeMigration.create_one_migration(
-                    attrs, methods))
-
-        return migrations
+    migration = _migration.Migration(**migration_info)
+    return migration
 
 
-class FakeServerMigration(object):
-    """Fake one or more server migrations."""
+def create_migrations(attrs=None, count=2):
+    """Create multiple fake migrations.
 
-    @staticmethod
-    def create_one_server_migration(attrs=None, methods=None):
-        """Create a fake server migration.
+    :param dict attrs: A dictionary with all attributes
+    :param int count: The number of migrations to fake
+    :return: A list of fake openstack.compute.v2.migration.Migration objects
+    """
+    migrations = []
+    for i in range(0, count):
+        migrations.append(create_one_migration(attrs))
 
-        :param dict attrs:
-            A dictionary with all attributes
-        :param dict methods:
-            A dictionary with all methods
-        :return:
-            A FakeResource object, with id, type, and so on
-        """
-        attrs = attrs or {}
-        methods = methods or {}
-
-        # Set default attributes.
-
-        migration_info = {
-            "created_at": "2016-01-29T13:42:02.000000",
-            "dest_compute": "compute2",
-            "dest_host": "1.2.3.4",
-            "dest_node": "node2",
-            "id": random.randint(1, 999),
-            "server_uuid": uuid.uuid4().hex,
-            "source_compute": "compute1",
-            "source_node": "node1",
-            "status": "running",
-            "memory_total_bytes": random.randint(1, 99999),
-            "memory_processed_bytes": random.randint(1, 99999),
-            "memory_remaining_bytes": random.randint(1, 99999),
-            "disk_total_bytes": random.randint(1, 99999),
-            "disk_processed_bytes": random.randint(1, 99999),
-            "disk_remaining_bytes": random.randint(1, 99999),
-            "updated_at": "2016-01-29T13:42:02.000000",
-            # added in 2.59
-            "uuid": uuid.uuid4().hex,
-            # added in 2.80
-            "user_id": uuid.uuid4().hex,
-            "project_id": uuid.uuid4().hex,
-        }
-
-        # Overwrite default attributes.
-        migration_info.update(attrs)
-
-        migration = fakes.FakeResource(
-            info=copy.deepcopy(migration_info),
-            methods=methods,
-            loaded=True)
-        return migration
+    return migrations
 
 
-class FakeVolumeAttachment(object):
-    """Fake one or more volume attachments (BDMs)."""
+def create_one_server_migration(attrs=None):
+    """Create a fake server migration.
 
-    @staticmethod
-    def create_one_volume_attachment(attrs=None, methods=None):
-        """Create a fake volume attachment.
+    :param dict attrs: A dictionary with all attributes
+    :return A fake openstack.compute.v2.server_migration.ServerMigration object
+    """
+    attrs = attrs or {}
 
-        :param dict attrs:
-            A dictionary with all attributes
-        :param dict methods:
-            A dictionary with all methods
-        :return:
-            A FakeResource object, with id, device, and so on
-        """
-        attrs = attrs or {}
-        methods = methods or {}
+    # Set default attributes.
 
-        # Set default attributes.
-        volume_attachment_info = {
-            "id": uuid.uuid4().hex,
-            "device": "/dev/sdb",
-            "serverId": uuid.uuid4().hex,
-            "volumeId": uuid.uuid4().hex,
-            # introduced in API microversion 2.70
-            "tag": "foo",
-            # introduced in API microversion 2.79
-            "delete_on_termination": True,
-            # introduced in API microversion 2.89
-            "attachment_id": uuid.uuid4().hex,
-            "bdm_uuid": uuid.uuid4().hex
-        }
+    migration_info = {
+        "created_at": "2016-01-29T13:42:02.000000",
+        "dest_compute": "compute2",
+        "dest_host": "1.2.3.4",
+        "dest_node": "node2",
+        "id": random.randint(1, 999),
+        "server_uuid": uuid.uuid4().hex,
+        "source_compute": "compute1",
+        "source_node": "node1",
+        "status": "running",
+        "memory_total_bytes": random.randint(1, 99999),
+        "memory_processed_bytes": random.randint(1, 99999),
+        "memory_remaining_bytes": random.randint(1, 99999),
+        "disk_total_bytes": random.randint(1, 99999),
+        "disk_processed_bytes": random.randint(1, 99999),
+        "disk_remaining_bytes": random.randint(1, 99999),
+        "updated_at": "2016-01-29T13:42:02.000000",
+        # added in 2.59
+        "uuid": uuid.uuid4().hex,
+        # added in 2.80
+        "user_id": uuid.uuid4().hex,
+        "project_id": uuid.uuid4().hex,
+    }
 
-        # Overwrite default attributes.
-        volume_attachment_info.update(attrs)
+    # Overwrite default attributes.
+    migration_info.update(attrs)
 
-        volume_attachment = fakes.FakeResource(
-            info=copy.deepcopy(volume_attachment_info),
-            methods=methods,
-            loaded=True)
-        return volume_attachment
+    migration = _server_migration.ServerMigration(**migration_info)
+    return migration
 
-    @staticmethod
-    def create_volume_attachments(attrs=None, methods=None, count=2):
-        """Create multiple fake volume attachments (BDMs).
 
-        :param dict attrs:
-            A dictionary with all attributes
-        :param dict methods:
-            A dictionary with all methods
-        :param int count:
-            The number of volume attachments to fake
-        :return:
-            A list of FakeResource objects faking the volume attachments.
-        """
-        volume_attachments = []
-        for i in range(0, count):
-            volume_attachments.append(
-                FakeVolumeAttachment.create_one_volume_attachment(
-                    attrs, methods))
+def create_server_migrations(attrs=None, methods=None, count=2):
+    """Create multiple server migrations.
 
-        return volume_attachments
+    :param dict attrs: A dictionary with all attributes
+    :param int count: The number of server migrations to fake
+    :return A list of fake
+        openstack.compute.v2.server_migration.ServerMigration objects
+    """
+    migrations = []
+    for i in range(0, count):
+        migrations.append(
+            create_one_server_migration(attrs, methods))
+
+    return migrations
+
+
+def create_one_volume_attachment(attrs=None):
+    """Create a fake volume attachment.
+
+    :param dict attrs: A dictionary with all attributes
+    :return: A fake openstack.compute.v2.volume_attachment.VolumeAttachment
+        object
+    """
+    attrs = attrs or {}
+
+    # Set default attributes.
+    volume_attachment_info = {
+        "id": uuid.uuid4().hex,
+        "device": "/dev/sdb",
+        "server_id": uuid.uuid4().hex,
+        "volume_id": uuid.uuid4().hex,
+        # introduced in API microversion 2.70
+        "tag": "foo",
+        # introduced in API microversion 2.79
+        "delete_on_termination": True,
+        # introduced in API microversion 2.89
+        "attachment_id": uuid.uuid4().hex,
+        "bdm_id": uuid.uuid4().hex,
+    }
+
+    # Overwrite default attributes.
+    volume_attachment_info.update(attrs)
+
+    return volume_attachment.VolumeAttachment(**volume_attachment_info)
+
+
+def create_volume_attachments(attrs=None, count=2):
+    """Create multiple fake volume attachments.
+
+    :param dict attrs: A dictionary with all attributes
+    :param int count: The number of volume attachments to fake
+    :return: A list of fake
+        openstack.compute.v2.volume_attachment.VolumeAttachment objects
+    """
+    volume_attachments = []
+    for i in range(0, count):
+        volume_attachments.append(create_one_volume_attachment(attrs))
+
+    return volume_attachments
+
+
+def create_one_hypervisor(attrs=None):
+    """Create a fake hypervisor.
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :return:
+        A FakeResource object, with id, hypervisor_hostname, and so on
+    """
+    attrs = attrs or {}
+
+    # Set default attributes.
+    hypervisor_info = {
+        'id': 'hypervisor-id-' + uuid.uuid4().hex,
+        'hypervisor_hostname': 'hypervisor-hostname-' + uuid.uuid4().hex,
+        'status': 'enabled',
+        'host_ip': '192.168.0.10',
+        'cpu_info': {
+            'aaa': 'aaa',
+        },
+        'free_disk_gb': 50,
+        'hypervisor_version': 2004001,
+        'disk_available_least': 50,
+        'local_gb': 50,
+        'free_ram_mb': 1024,
+        'service': {
+            'host': 'aaa',
+            'disabled_reason': None,
+            'id': 1,
+        },
+        'vcpus_used': 0,
+        'hypervisor_type': 'QEMU',
+        'local_gb_used': 0,
+        'vcpus': 4,
+        'memory_mb_used': 512,
+        'memory_mb': 1024,
+        'current_workload': 0,
+        'state': 'up',
+        'running_vms': 0,
+    }
+
+    # Overwrite default attributes.
+    hypervisor_info.update(attrs)
+
+    hypervisor = _hypervisor.Hypervisor(**hypervisor_info, loaded=True)
+    return hypervisor
+
+
+def create_hypervisors(attrs=None, count=2):
+    """Create multiple fake hypervisors.
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :param int count:
+        The number of hypervisors to fake
+    :return:
+        A list of FakeResource objects faking the hypervisors
+    """
+    hypervisors = []
+    for i in range(0, count):
+        hypervisors.append(create_one_hypervisor(attrs))
+
+    return hypervisors
+
+
+def create_one_server_group(attrs=None):
+    """Create a fake server group
+
+    :param dict attrs:
+        A dictionary with all attributes
+    :return:
+        A fake ServerGroup object, with id and other attributes
+    """
+    if attrs is None:
+        attrs = {}
+
+    # Set default attributes.
+    server_group_info = {
+        'id': 'server-group-id-' + uuid.uuid4().hex,
+        'member_ids': '',
+        'metadata': {},
+        'name': 'server-group-name-' + uuid.uuid4().hex,
+        'project_id': 'server-group-project-id-' + uuid.uuid4().hex,
+        'user_id': 'server-group-user-id-' + uuid.uuid4().hex,
+    }
+
+    # Overwrite default attributes.
+    server_group_info.update(attrs)
+
+    server_group = _server_group.ServerGroup(**server_group_info)
+    return server_group
+
+
+def create_one_server_interface(attrs=None):
+    """Create a fake SDK ServerInterface.
+
+    :param dict attrs: A dictionary with all attributes
+    :param dict methods: A dictionary with all methods
+    :return: A fake ServerInterface object with various attributes set
+    """
+    attrs = attrs or {}
+
+    # Set default attributes.
+    server_interface_info = {
+        "fixed_ips": uuid.uuid4().hex,
+        "mac_addr": "aa:aa:aa:aa:aa:aa",
+        "net_id": uuid.uuid4().hex,
+        "port_id": uuid.uuid4().hex,
+        "port_state": "ACTIVE",
+        "server_id": uuid.uuid4().hex,
+        # introduced in API microversion 2.70
+        "tag": "foo",
+    }
+
+    # Overwrite default attributes.
+    server_interface_info.update(attrs)
+
+    return _server_interface.ServerInterface(**server_interface_info)
