@@ -133,7 +133,7 @@ class TestFlavorCreate(TestFlavor):
         self.sdk_client.create_flavor.assert_called_once_with(**default_args)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_flavor_create_all_options(self):
 
@@ -202,7 +202,7 @@ class TestFlavorCreate(TestFlavor):
             self.sdk_client.get_flavor_access.assert_not_called()
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(tuple(cmp_data), data)
+        self.assertCountEqual(tuple(cmp_data), data)
 
     def test_flavor_create_other_options(self):
 
@@ -277,7 +277,7 @@ class TestFlavorCreate(TestFlavor):
         self.sdk_client.create_flavor_extra_specs.assert_called_with(
             create_flavor, props)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(cmp_data, data)
+        self.assertCountEqual(cmp_data, data)
 
     def test_public_flavor_create_with_project(self):
         arglist = [
@@ -350,7 +350,7 @@ class TestFlavorCreate(TestFlavor):
         self.sdk_client.create_flavor.assert_called_once_with(**args)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data_private, data)
+        self.assertCountEqual(self.data_private, data)
 
     def test_flavor_create_with_description_api_older(self):
         arglist = [
@@ -523,6 +523,7 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -550,6 +551,7 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -577,6 +579,7 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -604,6 +607,7 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, tuple(data))
@@ -631,9 +635,61 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns_long, columns)
-        self.assertItemsEqual(self.data_long, tuple(data))
+        self.assertCountEqual(self.data_long, tuple(data))
+
+    def test_flavor_list_long_no_extra_specs(self):
+        # use flavor with no extra specs for this test
+        flavor = compute_fakes.FakeFlavor.create_one_flavor(
+            attrs={"extra_specs": {}})
+        self.data = ((
+            flavor.id,
+            flavor.name,
+            flavor.ram,
+            flavor.disk,
+            flavor.ephemeral,
+            flavor.vcpus,
+            flavor.is_public,
+        ),)
+        self.data_long = (self.data[0] + (
+            flavor.swap,
+            flavor.rxtx_factor,
+            format_columns.DictColumn(flavor.extra_specs)
+        ),)
+        self.api_mock.side_effect = [[flavor], [], ]
+
+        self.sdk_client.flavors = self.api_mock
+        self.sdk_client.fetch_flavor_extra_specs = mock.Mock(return_value=None)
+
+        arglist = [
+            '--long',
+        ]
+        verifylist = [
+            ('long', True),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'is_public': True,
+        }
+
+        self.sdk_client.flavors.assert_called_with(
+            **kwargs
+        )
+        self.sdk_client.fetch_flavor_extra_specs.assert_called_once_with(
+            flavor)
+
+        self.assertEqual(self.columns_long, columns)
+        self.assertCountEqual(self.data_long, tuple(data))
 
     def test_flavor_list_min_disk_min_ram(self):
         arglist = [
@@ -662,6 +718,7 @@ class TestFlavorList(TestFlavor):
         self.sdk_client.flavors.assert_called_with(
             **kwargs
         )
+        self.sdk_client.fetch_flavor_extra_specs.assert_not_called()
 
         self.assertEqual(self.columns, columns)
         self.assertEqual(tuple(self.data), tuple(data))
@@ -951,7 +1008,7 @@ class TestFlavorShow(TestFlavor):
         columns, data = self.cmd.take_action(parsed_args)
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_private_flavor_show(self):
         private_flavor = compute_fakes.FakeFlavor.create_one_flavor(
@@ -991,7 +1048,7 @@ class TestFlavorShow(TestFlavor):
         self.sdk_client.get_flavor_access.assert_called_with(
             flavor=private_flavor.id)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(data_with_project, data)
+        self.assertCountEqual(data_with_project, data)
 
 
 class TestFlavorUnset(TestFlavor):
