@@ -10,8 +10,8 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib import exceptions
 
