@@ -13,12 +13,14 @@
 #   under the License.
 
 import copy
+from unittest import mock
 
-import mock
+from osc_lib import exceptions
 
 from openstackclient.identity.v3 import identity_provider
 from openstackclient.tests.unit import fakes
 from openstackclient.tests.unit.identity.v3 import fakes as identity_fakes
+from openstackclient.tests.unit import utils as test_utils
 
 
 class TestIdentityProvider(identity_fakes.TestFederatedIdentity):
@@ -90,7 +92,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_description(self):
         arglist = [
@@ -118,7 +120,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_id(self):
         arglist = [
@@ -146,7 +148,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_multiple(self):
         arglist = [
@@ -175,7 +177,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_remote_ids_file(self):
         arglist = [
@@ -208,7 +210,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_disabled(self):
 
@@ -251,7 +253,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
             identity_fakes.idp_id,
             identity_fakes.formatted_idp_remote_ids
         )
-        self.assertItemEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
 
     def test_create_identity_provider_domain_name(self):
         arglist = [
@@ -279,7 +281,7 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
 
     def test_create_identity_provider_domain_id(self):
         arglist = [
@@ -307,7 +309,87 @@ class TestIdentityProviderCreate(TestIdentityProvider):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemEqual(self.datalist, data)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_positive(self):
+        arglist = [
+            '--authorization-ttl', '60',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', 60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'remote_ids': None,
+            'description': None,
+            'domain_id': None,
+            'enabled': True,
+            'authorization_ttl': 60,
+        }
+
+        self.identity_providers_mock.create.assert_called_with(
+            id=identity_fakes.idp_id,
+            **kwargs
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_zero(self):
+        arglist = [
+            '--authorization-ttl', '0',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', 0),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        # Set expected values
+        kwargs = {
+            'remote_ids': None,
+            'description': None,
+            'domain_id': None,
+            'enabled': True,
+            'authorization_ttl': 0,
+        }
+
+        self.identity_providers_mock.create.assert_called_with(
+            id=identity_fakes.idp_id,
+            **kwargs
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_create_identity_provider_authttl_negative(self):
+        arglist = [
+            '--authorization-ttl', '-60',
+            identity_fakes.idp_id,
+        ]
+        verifylist = [
+            ('identity_provider_id', identity_fakes.idp_id),
+            ('authorization_ttl', -60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError, self.cmd.take_action,
+                          parsed_args)
+
+    def test_create_identity_provider_authttl_not_int(self):
+        arglist = [
+            '--authorization-ttl', 'spam',
+            identity_fakes.idp_id,
+        ]
+        verifylist = []
+        self.assertRaises(test_utils.ParserException, self.check_parser,
+                          self.cmd, arglist, verifylist)
 
 
 class TestIdentityProviderDelete(TestIdentityProvider):
@@ -383,7 +465,62 @@ class TestIdentityProviderList(TestIdentityProvider):
             identity_fakes.domain_id,
             identity_fakes.idp_description,
         ), )
-        self.assertListItemEqual(datalist, tuple(data))
+        self.assertCountEqual(datalist, tuple(data))
+
+    def test_identity_provider_list_ID_option(self):
+        arglist = ['--id',
+                   identity_fakes.idp_id]
+        verifylist = [
+            ('id', identity_fakes.idp_id)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        kwargs = {
+            'id': identity_fakes.idp_id
+        }
+        self.identity_providers_mock.list.assert_called_with(**kwargs)
+
+        collist = ('ID', 'Enabled', 'Domain ID', 'Description')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.idp_id,
+            True,
+            identity_fakes.domain_id,
+            identity_fakes.idp_description,
+        ), )
+        self.assertCountEqual(datalist, tuple(data))
+
+    def test_identity_provider_list_enabled_option(self):
+        arglist = ['--enabled']
+        verifylist = [
+            ('enabled', True)
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        kwargs = {
+            'enabled': True
+        }
+        self.identity_providers_mock.list.assert_called_with(**kwargs)
+
+        collist = ('ID', 'Enabled', 'Domain ID', 'Description')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.idp_id,
+            True,
+            identity_fakes.domain_id,
+            identity_fakes.idp_description,
+        ), )
+        self.assertCountEqual(datalist, tuple(data))
 
 
 class TestIdentityProviderSet(TestIdentityProvider):
@@ -624,6 +761,93 @@ class TestIdentityProviderSet(TestIdentityProvider):
 
         self.cmd.take_action(parsed_args)
 
+    def test_identity_provider_set_authttl_positive(self):
+        def prepare(self):
+            """Prepare fake return objects before the test is executed"""
+            updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
+            updated_idp['authorization_ttl'] = 60
+            resources = fakes.FakeResource(
+                None,
+                updated_idp,
+                loaded=True
+            )
+            self.identity_providers_mock.update.return_value = resources
+
+        prepare(self)
+        arglist = [
+            '--authorization-ttl', '60',
+            identity_fakes.idp_id
+        ]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', 60),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.identity_providers_mock.update.assert_called_with(
+            identity_fakes.idp_id,
+            authorization_ttl=60,
+        )
+
+    def test_identity_provider_set_authttl_zero(self):
+        def prepare(self):
+            """Prepare fake return objects before the test is executed"""
+            updated_idp = copy.deepcopy(identity_fakes.IDENTITY_PROVIDER)
+            updated_idp['authorization_ttl'] = 0
+            resources = fakes.FakeResource(
+                None,
+                updated_idp,
+                loaded=True
+            )
+            self.identity_providers_mock.update.return_value = resources
+
+        prepare(self)
+        arglist = [
+            '--authorization-ttl', '0',
+            identity_fakes.idp_id
+        ]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', 0),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.identity_providers_mock.update.assert_called_with(
+            identity_fakes.idp_id,
+            authorization_ttl=0,
+        )
+
+    def test_identity_provider_set_authttl_negative(self):
+        arglist = [
+            '--authorization-ttl', '-1',
+            identity_fakes.idp_id
+        ]
+        verifylist = [
+            ('identity_provider', identity_fakes.idp_id),
+            ('enable', False),
+            ('disable', False),
+            ('remote_id', None),
+            ('authorization_ttl', -1),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.assertRaises(exceptions.CommandError, self.cmd.take_action,
+                          parsed_args)
+
+    def test_identity_provider_set_authttl_not_int(self):
+        arglist = [
+            '--authorization-ttl', 'spam',
+            identity_fakes.idp_id
+        ]
+        verifylist = []
+        self.assertRaises(test_utils.ParserException, self.check_parser,
+                          self.cmd, arglist, verifylist)
+
 
 class TestIdentityProviderShow(TestIdentityProvider):
 
@@ -668,4 +892,4 @@ class TestIdentityProviderShow(TestIdentityProvider):
             identity_fakes.idp_id,
             identity_fakes.formatted_idp_remote_ids
         )
-        self.assertItemEqual(datalist, data)
+        self.assertCountEqual(datalist, data)
