@@ -206,7 +206,113 @@ class TestTrustList(TestTrust):
         # containing the data to be listed.
         columns, data = self.cmd.take_action(parsed_args)
 
-        self.trusts_mock.list.assert_called_with()
+        self.trusts_mock.list.assert_called_with(
+            trustor_user=None,
+            trustee_user=None,
+        )
+
+        collist = ('ID', 'Expires At', 'Impersonation', 'Project ID',
+                   'Trustee User ID', 'Trustor User ID')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.trust_id,
+            identity_fakes.trust_expires,
+            identity_fakes.trust_impersonation,
+            identity_fakes.project_id,
+            identity_fakes.user_id,
+            identity_fakes.user_id
+        ), )
+        self.assertEqual(datalist, tuple(data))
+
+    def test_trust_list_auth_user(self):
+        auth_ref = self.app.client_manager.auth_ref = mock.Mock()
+        auth_ref.user_id.return_value = identity_fakes.user_id
+
+        arglist = ['--auth-user']
+        verifylist = [
+            ('trustor', None),
+            ('trustee', None),
+            ('authuser', True),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.trusts_mock.list.assert_any_call(
+            trustor_user=self.users_mock.get()
+        )
+        self.trusts_mock.list.assert_any_call(
+            trustee_user=self.users_mock.get()
+        )
+
+        collist = ('ID', 'Expires At', 'Impersonation', 'Project ID',
+                   'Trustee User ID', 'Trustor User ID')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.trust_id,
+            identity_fakes.trust_expires,
+            identity_fakes.trust_impersonation,
+            identity_fakes.project_id,
+            identity_fakes.user_id,
+            identity_fakes.user_id
+        ), )
+        self.assertEqual(datalist, tuple(data))
+
+    def test_trust_list_trustee(self):
+        arglist = ['--trustee', identity_fakes.user_name]
+        verifylist = [
+            ('trustor', None),
+            ('trustee', identity_fakes.user_name),
+            ('authuser', False),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        print(self.trusts_mock.list.call_args_list)
+        self.trusts_mock.list.assert_any_call(
+            trustee_user=self.users_mock.get(),
+            trustor_user=None,
+        )
+
+        collist = ('ID', 'Expires At', 'Impersonation', 'Project ID',
+                   'Trustee User ID', 'Trustor User ID')
+        self.assertEqual(collist, columns)
+        datalist = ((
+            identity_fakes.trust_id,
+            identity_fakes.trust_expires,
+            identity_fakes.trust_impersonation,
+            identity_fakes.project_id,
+            identity_fakes.user_id,
+            identity_fakes.user_id
+        ), )
+        self.assertEqual(datalist, tuple(data))
+
+    def test_trust_list_trustor(self):
+        arglist = ['--trustor', identity_fakes.user_name]
+        verifylist = [
+            ('trustee', None),
+            ('trustor', identity_fakes.user_name),
+            ('authuser', False),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # In base command class Lister in cliff, abstract method take_action()
+        # returns a tuple containing the column names and an iterable
+        # containing the data to be listed.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        print(self.trusts_mock.list.call_args_list)
+        self.trusts_mock.list.assert_any_call(
+            trustor_user=self.users_mock.get(),
+            trustee_user=None,
+        )
 
         collist = ('ID', 'Expires At', 'Impersonation', 'Project ID',
                    'Trustee User ID', 'Trustor User ID')
