@@ -13,8 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from mock import call
+from unittest import mock
+from unittest.mock import call
 
 from osc_lib import exceptions
 
@@ -31,7 +31,7 @@ class TestFloatingIPPortForwarding(network_fakes.TestNetworkV2):
         self.network = self.app.client_manager.network
         self.floating_ip = (network_fakes.FakeFloatingIP.
                             create_one_floating_ip())
-        self.port = network_fakes.FakePort.create_one_port()
+        self.port = network_fakes.create_one_port()
         self.project = identity_fakes_v2.FakeProject.create_one_project()
         self.network.find_port = mock.Mock(return_value=self.port)
 
@@ -39,7 +39,6 @@ class TestFloatingIPPortForwarding(network_fakes.TestNetworkV2):
 class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
 
     def setUp(self):
-        project_id = ''
         super(TestCreateFloatingIPPortForwarding, self).setUp()
         self.new_port_forwarding = (
             network_fakes.FakeFloatingIPPortForwarding.
@@ -50,6 +49,18 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
                 }
             )
         )
+
+        self.new_port_forwarding_with_ranges = (
+            network_fakes.FakeFloatingIPPortForwarding.
+            create_one_port_forwarding(
+                use_range=True,
+                attrs={
+                    'internal_port_id': self.port.id,
+                    'floatingip_id': self.floating_ip.id,
+                }
+            )
+        )
+
         self.network.create_floating_ip_port_forwarding = mock.Mock(
             return_value=self.new_port_forwarding)
 
@@ -62,24 +73,28 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             self.app, self.namespace)
 
         self.columns = (
+            'description',
             'external_port',
+            'external_port_range',
             'floatingip_id',
             'id',
             'internal_ip_address',
             'internal_port',
             'internal_port_id',
-            'project_id',
+            'internal_port_range',
             'protocol'
         )
 
         self.data = (
+            self.new_port_forwarding.description,
             self.new_port_forwarding.external_port,
+            self.new_port_forwarding.external_port_range,
             self.new_port_forwarding.floatingip_id,
             self.new_port_forwarding.id,
             self.new_port_forwarding.internal_ip_address,
             self.new_port_forwarding.internal_port,
             self.new_port_forwarding.internal_port_id,
-            project_id,
+            self.new_port_forwarding.internal_port_range,
             self.new_port_forwarding.protocol,
         )
 
@@ -91,6 +106,160 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_create_all_options_with_range(self):
+        arglist = [
+            '--port', self.new_port_forwarding_with_ranges.internal_port_id,
+            '--internal-protocol-port',
+            self.new_port_forwarding_with_ranges.internal_port_range,
+            '--external-protocol-port',
+            self.new_port_forwarding_with_ranges.external_port_range,
+            '--protocol', self.new_port_forwarding_with_ranges.protocol,
+            self.new_port_forwarding_with_ranges.floatingip_id,
+            '--internal-ip-address',
+            self.new_port_forwarding_with_ranges.internal_ip_address,
+            '--description',
+            self.new_port_forwarding_with_ranges.description,
+        ]
+        verifylist = [
+            ('port', self.new_port_forwarding_with_ranges.internal_port_id),
+            ('internal_protocol_port',
+             self.new_port_forwarding_with_ranges.internal_port_range),
+            ('external_protocol_port',
+             self.new_port_forwarding_with_ranges.external_port_range),
+            ('protocol', self.new_port_forwarding_with_ranges.protocol),
+            ('floating_ip',
+             self.new_port_forwarding_with_ranges.floatingip_id),
+            ('internal_ip_address', self.new_port_forwarding_with_ranges.
+                internal_ip_address),
+            ('description', self.new_port_forwarding_with_ranges.description),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.create_floating_ip_port_forwarding.\
+            assert_called_once_with(
+                self.new_port_forwarding.floatingip_id,
+                **{
+                    'external_port_range':
+                        self.new_port_forwarding_with_ranges.
+                        external_port_range,
+                    'internal_ip_address':
+                        self.new_port_forwarding_with_ranges.
+                    internal_ip_address,
+                    'internal_port_range':
+                        self.new_port_forwarding_with_ranges.
+                        internal_port_range,
+                    'internal_port_id':
+                        self.new_port_forwarding_with_ranges.internal_port_id,
+                    'protocol': self.new_port_forwarding_with_ranges.protocol,
+                    'description':
+                        self.new_port_forwarding_with_ranges.description,
+                })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
+    def test_create_all_options_with_range_invalid_port_exception(self):
+        invalid_port_range = '999999:999999'
+        arglist = [
+            '--port', self.new_port_forwarding_with_ranges.internal_port_id,
+            '--internal-protocol-port', invalid_port_range,
+            '--external-protocol-port', invalid_port_range,
+            '--protocol', self.new_port_forwarding_with_ranges.protocol,
+            self.new_port_forwarding_with_ranges.floatingip_id,
+            '--internal-ip-address',
+            self.new_port_forwarding_with_ranges.internal_ip_address,
+            '--description',
+            self.new_port_forwarding_with_ranges.description,
+        ]
+        verifylist = [
+            ('port', self.new_port_forwarding_with_ranges.internal_port_id),
+            ('internal_protocol_port', invalid_port_range),
+            ('external_protocol_port', invalid_port_range),
+            ('protocol', self.new_port_forwarding_with_ranges.protocol),
+            ('floating_ip',
+             self.new_port_forwarding_with_ranges.floatingip_id),
+            ('internal_ip_address', self.new_port_forwarding_with_ranges.
+                internal_ip_address),
+            ('description', self.new_port_forwarding_with_ranges.description),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        msg = 'The port number range is <1-65535>'
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual(msg, str(e))
+            self.network.create_floating_ip_port_forwarding.assert_not_called()
+
+    def test_create_all_options_with_invalid_range_exception(self):
+        invalid_port_range = '80:70'
+        arglist = [
+            '--port', self.new_port_forwarding_with_ranges.internal_port_id,
+            '--internal-protocol-port', invalid_port_range,
+            '--external-protocol-port', invalid_port_range,
+            '--protocol', self.new_port_forwarding_with_ranges.protocol,
+            self.new_port_forwarding_with_ranges.floatingip_id,
+            '--internal-ip-address',
+            self.new_port_forwarding_with_ranges.internal_ip_address,
+            '--description',
+            self.new_port_forwarding_with_ranges.description,
+        ]
+        verifylist = [
+            ('port', self.new_port_forwarding_with_ranges.internal_port_id),
+            ('internal_protocol_port', invalid_port_range),
+            ('external_protocol_port', invalid_port_range),
+            ('protocol', self.new_port_forwarding_with_ranges.protocol),
+            ('floating_ip',
+             self.new_port_forwarding_with_ranges.floatingip_id),
+            ('internal_ip_address', self.new_port_forwarding_with_ranges.
+                internal_ip_address),
+            ('description', self.new_port_forwarding_with_ranges.description),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        msg = 'The last number in port range must be greater or equal to ' \
+              'the first'
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual(msg, str(e))
+            self.network.create_floating_ip_port_forwarding.assert_not_called()
+
+    def test_create_all_options_with_unmatch_ranges_exception(self):
+        internal_range = '80:90'
+        external_range = '8080:8100'
+        arglist = [
+            '--port', self.new_port_forwarding_with_ranges.internal_port_id,
+            '--internal-protocol-port', internal_range,
+            '--external-protocol-port', external_range,
+            '--protocol', self.new_port_forwarding_with_ranges.protocol,
+            self.new_port_forwarding_with_ranges.floatingip_id,
+            '--internal-ip-address',
+            self.new_port_forwarding_with_ranges.internal_ip_address,
+            '--description',
+            self.new_port_forwarding_with_ranges.description,
+        ]
+        verifylist = [
+            ('port', self.new_port_forwarding_with_ranges.internal_port_id),
+            ('internal_protocol_port', internal_range),
+            ('external_protocol_port', external_range),
+            ('protocol', self.new_port_forwarding_with_ranges.protocol),
+            ('floating_ip',
+             self.new_port_forwarding_with_ranges.floatingip_id),
+            ('internal_ip_address', self.new_port_forwarding_with_ranges.
+                internal_ip_address),
+            ('description', self.new_port_forwarding_with_ranges.description),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        msg = "The relation between internal and external ports does not " \
+              "match the pattern 1:N and N:N"
+        try:
+            self.cmd.take_action(parsed_args)
+            self.fail('CommandError should be raised.')
+        except exceptions.CommandError as e:
+            self.assertEqual(msg, str(e))
+            self.network.create_floating_ip_port_forwarding.assert_not_called()
+
     def test_create_all_options(self):
         arglist = [
             '--port', self.new_port_forwarding.internal_port_id,
@@ -102,15 +271,20 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             self.new_port_forwarding.floatingip_id,
             '--internal-ip-address',
             self.new_port_forwarding.internal_ip_address,
+            '--description',
+            self.new_port_forwarding.description,
         ]
         verifylist = [
             ('port', self.new_port_forwarding.internal_port_id),
-            ('internal_protocol_port', self.new_port_forwarding.internal_port),
-            ('external_protocol_port', self.new_port_forwarding.external_port),
+            ('internal_protocol_port',
+             str(self.new_port_forwarding.internal_port)),
+            ('external_protocol_port',
+             str(self.new_port_forwarding.external_port)),
             ('protocol', self.new_port_forwarding.protocol),
             ('floating_ip', self.new_port_forwarding.floatingip_id),
             ('internal_ip_address', self.new_port_forwarding.
                 internal_ip_address),
+            ('description', self.new_port_forwarding.description),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         columns, data = self.cmd.take_action(parsed_args)
@@ -126,6 +300,7 @@ class TestCreateFloatingIPPortForwarding(TestFloatingIPPortForwarding):
                     'internal_port_id': self.new_port_forwarding.
                     internal_port_id,
                     'protocol': self.new_port_forwarding.protocol,
+                    'description': self.new_port_forwarding.description,
                 })
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
@@ -250,8 +425,11 @@ class TestListFloatingIPPortForwarding(TestFloatingIPPortForwarding):
         'Internal Port ID',
         'Internal IP Address',
         'Internal Port',
+        'Internal Port Range',
         'External Port',
-        'Protocol'
+        'External Port Range',
+        'Protocol',
+        'Description',
     )
 
     def setUp(self):
@@ -271,8 +449,11 @@ class TestListFloatingIPPortForwarding(TestFloatingIPPortForwarding):
                 port_forwarding.internal_port_id,
                 port_forwarding.internal_ip_address,
                 port_forwarding.internal_port,
+                port_forwarding.internal_port_range,
                 port_forwarding.external_port,
+                port_forwarding.external_port_range,
                 port_forwarding.protocol,
+                port_forwarding.description,
             ))
         self.network.floating_ip_port_forwardings = mock.Mock(
             return_value=self.port_forwardings
@@ -325,7 +506,7 @@ class TestListFloatingIPPortForwarding(TestFloatingIPPortForwarding):
 
         query = {
             'internal_port_id': self.port_forwardings[0].internal_port_id,
-            'external_port': str(self.port_forwardings[0].external_port),
+            'external_port': self.port_forwardings[0].external_port,
             'protocol': self.port_forwardings[0].protocol,
         }
 
@@ -387,59 +568,78 @@ class TestSetFloatingIPPortForwarding(TestFloatingIPPortForwarding):
         self.assertIsNone(result)
 
     def test_set_all_thing(self):
-        arglist = [
+        arglist_single = [
             '--port', self.port.id,
             '--internal-ip-address', 'new_internal_ip_address',
             '--internal-protocol-port', '100',
             '--external-protocol-port', '200',
             '--protocol', 'tcp',
+            '--description', 'some description',
             self._port_forwarding.floatingip_id,
             self._port_forwarding.id,
         ]
-        verifylist = [
+        arglist_range = list(arglist_single)
+        arglist_range[5] = '100:110'
+        arglist_range[7] = '200:210'
+        verifylist_single = [
             ('port', self.port.id),
             ('internal_ip_address', 'new_internal_ip_address'),
-            ('internal_protocol_port', 100),
-            ('external_protocol_port', 200),
+            ('internal_protocol_port', '100'),
+            ('external_protocol_port', '200'),
             ('protocol', 'tcp'),
+            ('description', 'some description'),
             ('floating_ip', self._port_forwarding.floatingip_id),
             ('port_forwarding_id', self._port_forwarding.id),
         ]
-
-        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
-
-        result = self.cmd.take_action(parsed_args)
-        attrs = {
+        verifylist_range = list(verifylist_single)
+        verifylist_range[2] = ('internal_protocol_port', '100:110')
+        verifylist_range[3] = ('external_protocol_port', '200:210')
+        attrs_single = {
             'internal_port_id': self.port.id,
             'internal_ip_address': 'new_internal_ip_address',
             'internal_port': 100,
             'external_port': 200,
             'protocol': 'tcp',
+            'description': 'some description',
         }
-        self.network.update_floating_ip_port_forwarding.assert_called_with(
-            self._port_forwarding.floatingip_id,
-            self._port_forwarding.id,
-            **attrs
-        )
-        self.assertIsNone(result)
+        attrs_range = dict(attrs_single, internal_port_range='100:110',
+                           external_port_range='200:210')
+        attrs_range.pop('internal_port')
+        attrs_range.pop('external_port')
+
+        def run_and_validate(arglist, verifylist, attrs):
+            parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+            result = self.cmd.take_action(parsed_args)
+
+            self.network.update_floating_ip_port_forwarding.assert_called_with(
+                self._port_forwarding.floatingip_id,
+                self._port_forwarding.id,
+                **attrs
+            )
+            self.assertIsNone(result)
+
+        run_and_validate(arglist_single, verifylist_single, attrs_single)
+        run_and_validate(arglist_range, verifylist_range, attrs_range)
 
 
 class TestShowFloatingIPPortForwarding(TestFloatingIPPortForwarding):
 
     # The port forwarding to show.
     columns = (
+        'description',
         'external_port',
+        'external_port_range',
         'floatingip_id',
         'id',
         'internal_ip_address',
         'internal_port',
         'internal_port_id',
-        'project_id',
+        'internal_port_range',
         'protocol',
     )
 
     def setUp(self):
-        project_id = ''
         super(TestShowFloatingIPPortForwarding, self).setUp()
         self._port_forwarding = (
             network_fakes.FakeFloatingIPPortForwarding.
@@ -450,13 +650,15 @@ class TestShowFloatingIPPortForwarding(TestFloatingIPPortForwarding):
             )
         )
         self.data = (
+            self._port_forwarding.description,
             self._port_forwarding.external_port,
+            self._port_forwarding.external_port_range,
             self._port_forwarding.floatingip_id,
             self._port_forwarding.id,
             self._port_forwarding.internal_ip_address,
             self._port_forwarding.internal_port,
             self._port_forwarding.internal_port_id,
-            project_id,
+            self._port_forwarding.internal_port_range,
             self._port_forwarding.protocol,
         )
         self.network.find_floating_ip_port_forwarding = mock.Mock(
