@@ -46,9 +46,9 @@ class TestCreateNetworkIdentityV3(TestNetwork):
     project = identity_fakes_v3.FakeProject.create_one_project()
     domain = identity_fakes_v3.FakeDomain.create_one_domain()
     # The new network created.
-    _network = network_fakes.FakeNetwork.create_one_network(
+    _network = network_fakes.create_one_network(
         attrs={
-            'tenant_id': project.id,
+            'project_id': project.id,
             'availability_zone_hints': ["nova"],
         }
     )
@@ -59,12 +59,14 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         'admin_state_up',
         'availability_zone_hints',
         'availability_zones',
+        'created_at',
         'description',
         'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'is_vlan_transparent',
         'mtu',
         'name',
         'port_security_enabled',
@@ -76,14 +78,18 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         'router:external',
         'shared',
         'status',
+        'segments',
         'subnets',
         'tags',
+        'revision_number',
+        'updated_at',
     )
 
     data = (
-        network.AdminStateColumn(_network.admin_state_up),
+        network.AdminStateColumn(_network.is_admin_state_up),
         format_columns.ListColumn(_network.availability_zone_hints),
         format_columns.ListColumn(_network.availability_zones),
+        _network.created_at,
         _network.description,
         _network.dns_domain,
         _network.id,
@@ -99,10 +105,14 @@ class TestCreateNetworkIdentityV3(TestNetwork):
         _network.provider_segmentation_id,
         _network.qos_policy_id,
         network.RouterExternalColumn(_network.is_router_external),
-        _network.shared,
+        _network.is_shared,
+        _network.is_vlan_transparent,
         _network.status,
-        format_columns.ListColumn(_network.subnets),
+        _network.segments,
+        format_columns.ListColumn(_network.subnet_ids),
         format_columns.ListColumn(_network.tags),
+        _network.revision_number,
+        _network.updated_at,
     )
 
     def setUp(self):
@@ -145,7 +155,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'name': self._network.name,
         })
         self.assertFalse(self.network.set_tags.called)
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
     def test_create_all_options(self):
@@ -153,7 +163,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             "--disable",
             "--share",
             "--description", self._network.description,
-            "--mtu", self._network.mtu,
+            "--mtu", str(self._network.mtu),
             "--project", self.project.name,
             "--project-domain", self.domain.name,
             "--availability-zone-hint", "nova",
@@ -171,7 +181,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             ('disable', True),
             ('share', True),
             ('description', self._network.description),
-            ('mtu', self._network.mtu),
+            ('mtu', str(self._network.mtu)),
             ('project', self.project.name),
             ('project_domain', self.domain.name),
             ('availability_zone_hints', ["nova"]),
@@ -196,9 +206,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'name': self._network.name,
             'shared': True,
             'description': self._network.description,
-            'mtu': self._network.mtu,
-            # TODO(dtroyer): Remove tenant_id when we clean up the SDK refactor
-            'tenant_id': self.project.id,
+            'mtu': str(self._network.mtu),
             'project_id': self.project.id,
             'is_default': True,
             'router:external': True,
@@ -210,7 +218,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'port_security_enabled': True,
             'dns_domain': 'example.org.',
         })
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
     def test_create_other_options(self):
@@ -237,7 +245,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
             'shared': False,
             'port_security_enabled': False,
         })
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
@@ -269,7 +277,7 @@ class TestCreateNetworkIdentityV3(TestNetwork):
                 tests_utils.CompareBySet(['red', 'blue']))
         else:
             self.assertFalse(self.network.set_tags.called)
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
@@ -283,20 +291,21 @@ class TestCreateNetworkIdentityV2(TestNetwork):
 
     project = identity_fakes_v2.FakeProject.create_one_project()
     # The new network created.
-    _network = network_fakes.FakeNetwork.create_one_network(
-        attrs={'tenant_id': project.id}
+    _network = network_fakes.create_one_network(
+        attrs={'project_id': project.id}
     )
-
     columns = (
         'admin_state_up',
         'availability_zone_hints',
         'availability_zones',
+        'created_at',
         'description',
         'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'is_vlan_transparent',
         'mtu',
         'name',
         'port_security_enabled',
@@ -308,14 +317,18 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         'router:external',
         'shared',
         'status',
+        'segments',
         'subnets',
         'tags',
+        'revision_number',
+        'updated_at',
     )
 
     data = (
-        network.AdminStateColumn(_network.admin_state_up),
+        network.AdminStateColumn(_network.is_admin_state_up),
         format_columns.ListColumn(_network.availability_zone_hints),
         format_columns.ListColumn(_network.availability_zones),
+        _network.created_at,
         _network.description,
         _network.dns_domain,
         _network.id,
@@ -331,10 +344,14 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         _network.provider_segmentation_id,
         _network.qos_policy_id,
         network.RouterExternalColumn(_network.is_router_external),
-        _network.shared,
+        _network.is_shared,
+        _network.is_vlan_transparent,
         _network.status,
-        format_columns.ListColumn(_network.subnets),
+        _network.segments,
+        format_columns.ListColumn(_network.subnet_ids),
         format_columns.ListColumn(_network.tags),
+        _network.revision_number,
+        _network.updated_at,
     )
 
     def setUp(self):
@@ -379,12 +396,10 @@ class TestCreateNetworkIdentityV2(TestNetwork):
         self.network.create_network.assert_called_once_with(**{
             'admin_state_up': True,
             'name': self._network.name,
-            # TODO(dtroyer): Remove tenant_id when we clean up the SDK refactor
-            'tenant_id': self.project.id,
             'project_id': self.project.id,
         })
         self.assertFalse(self.network.set_tags.called)
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
     def test_create_with_domain_identityv2(self):
@@ -417,11 +432,11 @@ class TestDeleteNetwork(TestNetwork):
         super(TestDeleteNetwork, self).setUp()
 
         # The networks to delete
-        self._networks = network_fakes.FakeNetwork.create_networks(count=3)
+        self._networks = network_fakes.create_networks(count=3)
 
         self.network.delete_network = mock.Mock(return_value=None)
 
-        self.network.find_network = network_fakes.FakeNetwork.get_networks(
+        self.network.find_network = network_fakes.get_networks(
             networks=self._networks)
 
         # Get the command object to test
@@ -499,7 +514,7 @@ class TestDeleteNetwork(TestNetwork):
 class TestListNetwork(TestNetwork):
 
     # The networks going to be listed up.
-    _network = network_fakes.FakeNetwork.create_networks(count=3)
+    _network = network_fakes.create_networks(count=3)
 
     columns = (
         'ID',
@@ -525,7 +540,7 @@ class TestListNetwork(TestNetwork):
         data.append((
             net.id,
             net.name,
-            format_columns.ListColumn(net.subnets),
+            format_columns.ListColumn(net.subnet_ids),
         ))
 
     data_long = []
@@ -535,9 +550,9 @@ class TestListNetwork(TestNetwork):
             net.name,
             net.status,
             net.project_id,
-            network.AdminStateColumn(net.admin_state_up),
-            net.shared,
-            format_columns.ListColumn(net.subnets),
+            network.AdminStateColumn(net.is_admin_state_up),
+            net.is_shared,
+            format_columns.ListColumn(net.subnet_ids),
             net.provider_network_type,
             network.RouterExternalColumn(net.is_router_external),
             format_columns.ListColumn(net.availability_zones),
@@ -553,7 +568,7 @@ class TestListNetwork(TestNetwork):
         self.network.networks = mock.Mock(return_value=self._network)
 
         self._agent = \
-            network_fakes.FakeNetworkAgent.create_one_network_agent()
+            network_fakes.create_one_network_agent()
         self.network.get_agent = mock.Mock(return_value=self._agent)
 
         self.network.dhcp_agent_hosting_networks = mock.Mock(
@@ -704,7 +719,7 @@ class TestListNetwork(TestNetwork):
 
         columns, data = self.cmd.take_action(parsed_args)
         self.network.networks.assert_called_once_with(
-            **{'tenant_id': project.id, 'project_id': project.id}
+            **{'project_id': project.id}
         )
 
         self.assertEqual(self.columns, columns)
@@ -723,7 +738,7 @@ class TestListNetwork(TestNetwork):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.networks.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -844,13 +859,12 @@ class TestListNetwork(TestNetwork):
             ('agent_id', self._agent.id),
         ]
 
-        attrs = {self._agent, }
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
 
         self.network.dhcp_agent_hosting_networks.assert_called_once_with(
-            *attrs)
+            self._agent)
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(list(data), list(self.data))
@@ -884,7 +898,7 @@ class TestListNetwork(TestNetwork):
 class TestSetNetwork(TestNetwork):
 
     # The network to set.
-    _network = network_fakes.FakeNetwork.create_one_network(
+    _network = network_fakes.create_one_network(
         {'tags': ['green', 'red']})
     qos_policy = (network_fakes.FakeNetworkQosPolicy.
                   create_one_qos_policy(attrs={'id': _network.qos_policy_id}))
@@ -1029,18 +1043,19 @@ class TestSetNetwork(TestNetwork):
 class TestShowNetwork(TestNetwork):
 
     # The network to show.
-    _network = network_fakes.FakeNetwork.create_one_network()
-
+    _network = network_fakes.create_one_network()
     columns = (
         'admin_state_up',
         'availability_zone_hints',
         'availability_zones',
+        'created_at',
         'description',
         'dns_domain',
         'id',
         'ipv4_address_scope',
         'ipv6_address_scope',
         'is_default',
+        'is_vlan_transparent',
         'mtu',
         'name',
         'port_security_enabled',
@@ -1052,14 +1067,18 @@ class TestShowNetwork(TestNetwork):
         'router:external',
         'shared',
         'status',
+        'segments',
         'subnets',
         'tags',
+        'revision_number',
+        'updated_at',
     )
 
     data = (
-        network.AdminStateColumn(_network.admin_state_up),
+        network.AdminStateColumn(_network.is_admin_state_up),
         format_columns.ListColumn(_network.availability_zone_hints),
         format_columns.ListColumn(_network.availability_zones),
+        _network.created_at,
         _network.description,
         _network.dns_domain,
         _network.id,
@@ -1075,10 +1094,14 @@ class TestShowNetwork(TestNetwork):
         _network.provider_segmentation_id,
         _network.qos_policy_id,
         network.RouterExternalColumn(_network.is_router_external),
-        _network.shared,
+        _network.is_shared,
+        _network.is_vlan_transparent,
         _network.status,
-        format_columns.ListColumn(_network.subnets),
+        _network.segments,
+        format_columns.ListColumn(_network.subnet_ids),
         format_columns.ListColumn(_network.tags),
+        _network.revision_number,
+        _network.updated_at,
     )
 
     def setUp(self):
@@ -1110,14 +1133,14 @@ class TestShowNetwork(TestNetwork):
         self.network.find_network.assert_called_once_with(
             self._network.name, ignore_missing=False)
 
-        self.assertEqual(self.columns, columns)
+        self.assertEqual(set(self.columns), set(columns))
         self.assertCountEqual(self.data, data)
 
 
 class TestUnsetNetwork(TestNetwork):
 
     # The network to set.
-    _network = network_fakes.FakeNetwork.create_one_network(
+    _network = network_fakes.create_one_network(
         {'tags': ['green', 'red']})
     qos_policy = (network_fakes.FakeNetworkQosPolicy.
                   create_one_qos_policy(attrs={'id': _network.qos_policy_id}))
