@@ -37,15 +37,15 @@ class TestNetworkRBAC(network_fakes.TestNetworkV2):
 @ddt.ddt
 class TestCreateNetworkRBAC(TestNetworkRBAC):
 
-    network_object = network_fakes.FakeNetwork.create_one_network()
+    network_object = network_fakes.create_one_network()
     qos_object = network_fakes.FakeNetworkQosPolicy.create_one_qos_policy()
     sg_object = network_fakes.FakeNetworkSecGroup.create_one_security_group()
-    as_object = network_fakes.FakeAddressScope.create_one_address_scope()
+    as_object = network_fakes.create_one_address_scope()
     snp_object = network_fakes.FakeSubnetPool.create_one_subnet_pool()
-    ag_object = network_fakes.FakeAddressGroup.create_one_address_group()
+    ag_object = network_fakes.create_one_address_group()
     project = identity_fakes_v3.FakeProject.create_one_project()
-    rbac_policy = network_fakes.FakeNetworkRBAC.create_one_network_rbac(
-        attrs={'tenant_id': project.id,
+    rbac_policy = network_fakes.create_one_network_rbac(
+        attrs={'project_id': project.id,
                'target_tenant': project.id,
                'object_id': network_object.id}
     )
@@ -64,8 +64,8 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         rbac_policy.id,
         rbac_policy.object_id,
         rbac_policy.object_type,
-        rbac_policy.tenant_id,
-        rbac_policy.target_tenant,
+        rbac_policy.project_id,
+        rbac_policy.target_project_id,
     ]
 
     def setUp(self):
@@ -120,13 +120,13 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         arglist = [
             '--action', self.rbac_policy.action,
             '--type', 'invalid_type',
-            '--target-project', self.rbac_policy.target_tenant,
+            '--target-project', self.rbac_policy.target_project_id,
             self.rbac_policy.object_id,
         ]
         verifylist = [
             ('action', self.rbac_policy.action),
             ('type', 'invalid_type'),
-            ('target-project', self.rbac_policy.target_tenant),
+            ('target-project', self.rbac_policy.target_project_id),
             ('rbac_policy', self.rbac_policy.id),
         ]
 
@@ -137,13 +137,13 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         arglist = [
             '--type', self.rbac_policy.object_type,
             '--action', 'invalid_action',
-            '--target-project', self.rbac_policy.target_tenant,
+            '--target-project', self.rbac_policy.target_project_id,
             self.rbac_policy.object_id,
         ]
         verifylist = [
             ('type', self.rbac_policy.object_type),
             ('action', 'invalid_action'),
-            ('target-project', self.rbac_policy.target_tenant),
+            ('target-project', self.rbac_policy.target_project_id),
             ('rbac_policy', self.rbac_policy.id),
         ]
 
@@ -154,13 +154,13 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         arglist = [
             '--type', self.rbac_policy.object_type,
             '--action', self.rbac_policy.action,
-            '--target-project', self.rbac_policy.target_tenant,
+            '--target-project', self.rbac_policy.target_project_id,
             self.rbac_policy.object_id,
         ]
         verifylist = [
             ('type', self.rbac_policy.object_type),
             ('action', self.rbac_policy.action),
-            ('target_project', self.rbac_policy.target_tenant),
+            ('target_project', self.rbac_policy.target_project_id),
             ('rbac_object', self.rbac_policy.object_id),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -172,7 +172,7 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
             'object_id': self.rbac_policy.object_id,
             'object_type': self.rbac_policy.object_type,
             'action': self.rbac_policy.action,
-            'target_tenant': self.rbac_policy.target_tenant,
+            'target_tenant': self.rbac_policy.target_project_id,
         })
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
@@ -205,8 +205,8 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         arglist = [
             '--type', self.rbac_policy.object_type,
             '--action', self.rbac_policy.action,
-            '--target-project', self.rbac_policy.target_tenant,
-            '--project', self.rbac_policy.tenant_id,
+            '--target-project', self.rbac_policy.target_project_id,
+            '--project', self.rbac_policy.project_id,
             '--project-domain', self.project.domain_id,
             '--target-project-domain', self.project.domain_id,
             self.rbac_policy.object_id,
@@ -214,8 +214,8 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         verifylist = [
             ('type', self.rbac_policy.object_type),
             ('action', self.rbac_policy.action),
-            ('target_project', self.rbac_policy.target_tenant),
-            ('project', self.rbac_policy.tenant_id),
+            ('target_project', self.rbac_policy.target_project_id),
+            ('project', self.rbac_policy.project_id),
             ('project_domain', self.project.domain_id),
             ('target_project_domain', self.project.domain_id),
             ('rbac_object', self.rbac_policy.object_id),
@@ -229,8 +229,8 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
             'object_id': self.rbac_policy.object_id,
             'object_type': self.rbac_policy.object_type,
             'action': self.rbac_policy.action,
-            'target_tenant': self.rbac_policy.target_tenant,
-            'tenant_id': self.rbac_policy.tenant_id,
+            'target_tenant': self.rbac_policy.target_project_id,
+            'project_id': self.rbac_policy.project_id,
         })
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
@@ -251,13 +251,13 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
         arglist = [
             '--type', obj_type,
             '--action', self.rbac_policy.action,
-            '--target-project', self.rbac_policy.target_tenant,
+            '--target-project', self.rbac_policy.target_project_id,
             obj_fake.name,
         ]
         verifylist = [
             ('type', obj_type),
             ('action', self.rbac_policy.action),
-            ('target_project', self.rbac_policy.target_tenant),
+            ('target_project', self.rbac_policy.target_project_id),
             ('rbac_object', obj_fake.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -269,15 +269,15 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
             'object_id': obj_fake.id,
             'object_type': obj_type,
             'action': self.rbac_policy.action,
-            'target_tenant': self.rbac_policy.target_tenant,
+            'target_tenant': self.rbac_policy.target_project_id,
         })
         self.data = [
             self.rbac_policy.action,
             self.rbac_policy.id,
             obj_fake.id,
             obj_type,
-            self.rbac_policy.tenant_id,
-            self.rbac_policy.target_tenant,
+            self.rbac_policy.project_id,
+            self.rbac_policy.target_project_id,
         ]
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, list(data))
@@ -285,13 +285,13 @@ class TestCreateNetworkRBAC(TestNetworkRBAC):
 
 class TestDeleteNetworkRBAC(TestNetworkRBAC):
 
-    rbac_policies = network_fakes.FakeNetworkRBAC.create_network_rbacs(count=2)
+    rbac_policies = network_fakes.create_network_rbacs(count=2)
 
     def setUp(self):
         super(TestDeleteNetworkRBAC, self).setUp()
         self.network.delete_rbac_policy = mock.Mock(return_value=None)
         self.network.find_rbac_policy = (
-            network_fakes.FakeNetworkRBAC.get_network_rbacs(
+            network_fakes.get_network_rbacs(
                 rbac_policies=self.rbac_policies)
         )
 
@@ -368,7 +368,7 @@ class TestDeleteNetworkRBAC(TestNetworkRBAC):
 class TestListNetworkRABC(TestNetworkRBAC):
 
     # The network rbac policies going to be listed up.
-    rbac_policies = network_fakes.FakeNetworkRBAC.create_network_rbacs(count=3)
+    rbac_policies = network_fakes.create_network_rbacs(count=3)
 
     columns = (
         'ID',
@@ -405,6 +405,9 @@ class TestListNetworkRABC(TestNetworkRBAC):
 
         self.network.rbac_policies = mock.Mock(return_value=self.rbac_policies)
 
+        self.project = identity_fakes_v3.FakeProject.create_one_project()
+        self.projects_mock.get.return_value = self.project
+
     def test_network_rbac_list(self):
         arglist = []
         verifylist = []
@@ -466,11 +469,27 @@ class TestListNetworkRABC(TestNetworkRBAC):
         self.assertEqual(self.columns_long, columns)
         self.assertEqual(self.data_long, list(data))
 
+    def test_network_rbac_list_target_project_opt(self):
+        arglist = [
+            '--target-project', self.rbac_policies[0].target_project_id, ]
+        verifylist = [
+            ('target_project', self.rbac_policies[0].target_project_id)]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        # DisplayCommandBase.take_action() returns two tuples
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.network.rbac_policies.assert_called_with(**{
+            'target_project_id': self.project.id
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, list(data))
+
 
 class TestSetNetworkRBAC(TestNetworkRBAC):
 
     project = identity_fakes_v3.FakeProject.create_one_project()
-    rbac_policy = network_fakes.FakeNetworkRBAC.create_one_network_rbac(
+    rbac_policy = network_fakes.create_one_network_rbac(
         attrs={'target_tenant': project.id})
 
     def setUp(self):
@@ -525,7 +544,7 @@ class TestSetNetworkRBAC(TestNetworkRBAC):
 
 class TestShowNetworkRBAC(TestNetworkRBAC):
 
-    rbac_policy = network_fakes.FakeNetworkRBAC.create_one_network_rbac()
+    rbac_policy = network_fakes.create_one_network_rbac()
 
     columns = (
         'action',
@@ -541,8 +560,8 @@ class TestShowNetworkRBAC(TestNetworkRBAC):
         rbac_policy.id,
         rbac_policy.object_id,
         rbac_policy.object_type,
-        rbac_policy.tenant_id,
-        rbac_policy.target_tenant,
+        rbac_policy.project_id,
+        rbac_policy.target_project_id,
     ]
 
     def setUp(self):
