@@ -36,7 +36,7 @@ class TestRouter(network_fakes.TestNetworkV2):
 class TestAddPortToRouter(TestRouter):
     '''Add port to Router '''
 
-    _port = network_fakes.FakePort.create_one_port()
+    _port = network_fakes.create_one_port()
     _router = network_fakes.FakeRouter.create_one_router(
         attrs={'port': _port.id})
 
@@ -141,7 +141,7 @@ class TestCreateRouter(TestRouter):
         new_router.ha,
         new_router.id,
         new_router.name,
-        new_router.tenant_id,
+        new_router.project_id,
         router.RoutesColumn(new_router.routes),
         new_router.status,
         format_columns.ListColumn(new_router.tags),
@@ -184,7 +184,44 @@ class TestCreateRouter(TestRouter):
         })
         self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
+
+    def test_create_with_gateway(self):
+        _network = network_fakes.create_one_network()
+        _subnet = network_fakes.FakeSubnet.create_one_subnet()
+        self.network.find_network = mock.Mock(return_value=_network)
+        self.network.find_subnet = mock.Mock(return_value=_subnet)
+        arglist = [
+            self.new_router.name,
+            '--external-gateway', _network.name,
+            '--enable-snat',
+            '--fixed-ip', 'ip-address=2001:db8::1'
+        ]
+        verifylist = [
+            ('name', self.new_router.name),
+            ('enable', True),
+            ('distributed', False),
+            ('ha', False),
+            ('external_gateway', _network.name),
+            ('enable_snat', True),
+            ('fixed_ip', [{'ip-address': '2001:db8::1'}]),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_router.assert_called_once_with(**{
+            'admin_state_up': True,
+            'name': self.new_router.name,
+            'external_gateway_info': {
+                'network_id': _network.id,
+                'enable_snat': True,
+                'external_fixed_ips': [{'ip_address': '2001:db8::1'}],
+            },
+        })
+        self.assertFalse(self.network.set_tags.called)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, data)
 
     def _test_create_with_ha_options(self, option, ha):
         arglist = [
@@ -208,7 +245,7 @@ class TestCreateRouter(TestRouter):
             'ha': ha,
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_ha_option(self):
         self._test_create_with_ha_options('--ha', True)
@@ -237,7 +274,7 @@ class TestCreateRouter(TestRouter):
             'distributed': distributed,
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_distributed_option(self):
         self._test_create_with_distributed_options('--distributed', True)
@@ -268,7 +305,7 @@ class TestCreateRouter(TestRouter):
         })
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def _test_create_with_tag(self, add_tags=True):
         arglist = [self.new_router.name]
@@ -301,7 +338,7 @@ class TestCreateRouter(TestRouter):
         else:
             self.assertFalse(self.network.set_tags.called)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_create_with_tags(self):
         self._test_create_with_tag(add_tags=True)
@@ -423,7 +460,7 @@ class TestListRouter(TestRouter):
             r.name,
             r.status,
             router.AdminStateColumn(r.admin_state_up),
-            r.tenant_id,
+            r.project_id,
             r.distributed,
             r.ha,
         ))
@@ -475,8 +512,7 @@ class TestListRouter(TestRouter):
         self.network.routers = mock.Mock(return_value=self.routers)
         self.network.find_extension = mock.Mock(return_value=self._extensions)
         self.network.find_router = mock.Mock(return_value=self.routers[0])
-        self._testagent = \
-            network_fakes.FakeNetworkAgent.create_one_network_agent()
+        self._testagent = network_fakes.create_one_network_agent()
         self.network.get_agent = mock.Mock(return_value=self._testagent)
         self.network.get_router = mock.Mock(return_value=self.routers[0])
 
@@ -494,7 +530,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_no_ha_no_distributed(self):
         _routers = network_fakes.FakeRouter.create_routers({
@@ -531,7 +567,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long, columns)
-        self.assertItemsEqual(self.data_long, list(data))
+        self.assertCountEqual(self.data_long, list(data))
 
     def test_router_list_long_no_az(self):
         arglist = [
@@ -552,7 +588,7 @@ class TestListRouter(TestRouter):
 
         self.network.routers.assert_called_once_with()
         self.assertEqual(self.columns_long_no_az, columns)
-        self.assertItemsEqual(self.data_long_no_az, list(data))
+        self.assertCountEqual(self.data_long_no_az, list(data))
 
     def test_list_name(self):
         test_name = "fakename"
@@ -570,7 +606,7 @@ class TestListRouter(TestRouter):
             **{'name': test_name}
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_enable(self):
         arglist = [
@@ -587,7 +623,7 @@ class TestListRouter(TestRouter):
             **{'admin_state_up': True, 'is_admin_state_up': True}
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_disable(self):
         arglist = [
@@ -605,7 +641,7 @@ class TestListRouter(TestRouter):
         )
 
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_project(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -619,11 +655,11 @@ class TestListRouter(TestRouter):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_project_domain(self):
         project = identity_fakes_v3.FakeProject.create_one_project()
@@ -639,11 +675,11 @@ class TestListRouter(TestRouter):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.routers.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_router_list_agents_no_args(self):
         arglist = [
@@ -671,7 +707,7 @@ class TestListRouter(TestRouter):
         self.network.agent_hosted_routers(
             *attrs)
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
     def test_list_with_tag_options(self):
         arglist = [
@@ -696,13 +732,13 @@ class TestListRouter(TestRouter):
                'not_any_tags': 'black,white'}
         )
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, list(data))
+        self.assertCountEqual(self.data, list(data))
 
 
 class TestRemovePortFromRouter(TestRouter):
     '''Remove port from a Router '''
 
-    _port = network_fakes.FakePort.create_one_port()
+    _port = network_fakes.create_one_port()
     _router = network_fakes.FakeRouter.create_one_router(
         attrs={'port': _port.id})
 
@@ -920,7 +956,7 @@ class TestSetRouter(TestRouter):
 
     # The router to set.
     _default_route = {'destination': '10.20.20.0/24', 'nexthop': '10.20.30.1'}
-    _network = network_fakes.FakeNetwork.create_one_network()
+    _network = network_fakes.create_one_network()
     _subnet = network_fakes.FakeSubnet.create_one_subnet()
     _router = network_fakes.FakeRouter.create_one_router(
         attrs={'routes': [_default_route],
@@ -1327,7 +1363,7 @@ class TestShowRouter(TestRouter):
 
     # The router to set.
     _router = network_fakes.FakeRouter.create_one_router()
-    _port = network_fakes.FakePort.create_one_port({
+    _port = network_fakes.create_one_port({
         'device_owner': 'network:router_interface',
         'device_id': _router.id
     })
@@ -1364,7 +1400,7 @@ class TestShowRouter(TestRouter):
         _router.id,
         router.RouterInfoColumn(_router.interfaces_info),
         _router.name,
-        _router.tenant_id,
+        _router.project_id,
         router.RoutesColumn(_router.routes),
         _router.status,
         format_columns.ListColumn(_router.tags),
@@ -1403,7 +1439,7 @@ class TestShowRouter(TestRouter):
             'device_id': self._router.id
         })
         self.assertEqual(self.columns, columns)
-        self.assertItemsEqual(self.data, data)
+        self.assertCountEqual(self.data, data)
 
     def test_show_no_ha_no_distributed(self):
         _router = network_fakes.FakeRouter.create_one_router({
@@ -1448,7 +1484,7 @@ class TestUnsetRouter(TestRouter):
 
     def setUp(self):
         super(TestUnsetRouter, self).setUp()
-        self.fake_network = network_fakes.FakeNetwork.create_one_network()
+        self.fake_network = network_fakes.create_one_network()
         self.fake_qos_policy = (
             network_fakes.FakeNetworkQosPolicy.create_one_qos_policy())
         self._testrouter = network_fakes.FakeRouter.create_one_router(
