@@ -44,7 +44,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv4 subnet to be created with mostly default values
         self._subnet = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
             }
         )
 
@@ -55,7 +55,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv4 subnet to be created using a specific subnet pool
         self._subnet_from_pool = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
                 'subnetpool_id': self._subnet_pool.id,
                 'dns_nameservers': ['8.8.8.8',
                                     '8.8.4.4'],
@@ -71,7 +71,7 @@ class TestCreateSubnet(TestSubnet):
         # An IPv6 subnet to be created with most options specified
         self._subnet_ipv6 = network_fakes.FakeSubnet.create_one_subnet(
             attrs={
-                'tenant_id': self.project.id,
+                'project_id': self.project.id,
                 'cidr': 'fe80:0:0:a00a::/64',
                 'enable_dhcp': True,
                 'dns_nameservers': ['fe80:27ff:a00a:f00f::ffff',
@@ -95,7 +95,7 @@ class TestCreateSubnet(TestSubnet):
         )
 
         # The network to be returned from find_network
-        self._network = network_fakes.FakeNetwork.create_one_network(
+        self._network = network_fakes.create_one_network(
             attrs={
                 'id': self._subnet.network_id,
             }
@@ -103,7 +103,7 @@ class TestCreateSubnet(TestSubnet):
 
         # The network segment to be returned from find_segment
         self._network_segment = \
-            network_fakes.FakeNetworkSegment.create_one_network_segment(
+            network_fakes.create_one_network_segment(
                 attrs={
                     'network_id': self._subnet.network_id,
                 }
@@ -661,7 +661,7 @@ class TestListSubnet(TestSubnet):
             subnet.name,
             subnet.network_id,
             subnet.cidr,
-            subnet.tenant_id,
+            subnet.project_id,
             subnet.enable_dhcp,
             format_columns.ListColumn(subnet.dns_nameservers),
             subnet_v2.AllocationPoolsColumn(subnet.allocation_pools),
@@ -783,7 +783,7 @@ class TestListSubnet(TestSubnet):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
@@ -821,14 +821,14 @@ class TestListSubnet(TestSubnet):
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = self.cmd.take_action(parsed_args)
-        filters = {'tenant_id': project.id, 'project_id': project.id}
+        filters = {'project_id': project.id}
 
         self.network.subnets.assert_called_once_with(**filters)
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
     def test_subnet_list_network(self):
-        network = network_fakes.FakeNetwork.create_one_network()
+        network = network_fakes.create_one_network()
         self.network.find_network = mock.Mock(return_value=network)
         arglist = [
             '--network', network.id,
@@ -899,6 +899,48 @@ class TestListSubnet(TestSubnet):
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.data, list(data))
 
+    def test_subnet_list_subnetpool_by_name(self):
+        subnet_pool = network_fakes.FakeSubnetPool.create_one_subnet_pool()
+        subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'subnetpool_id': subnet_pool.id})
+        self.network.find_network = mock.Mock(return_value=subnet)
+        self.network.find_subnet_pool = mock.Mock(return_value=subnet_pool)
+        arglist = [
+            '--subnet-pool', subnet_pool.name,
+        ]
+        verifylist = [
+            ('subnet_pool', subnet_pool.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'subnetpool_id': subnet_pool.id}
+
+        self.network.subnets.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
+
+    def test_subnet_list_subnetpool_by_id(self):
+        subnet_pool = network_fakes.FakeSubnetPool.create_one_subnet_pool()
+        subnet = network_fakes.FakeSubnet.create_one_subnet(
+            {'subnetpool_id': subnet_pool.id})
+        self.network.find_network = mock.Mock(return_value=subnet)
+        self.network.find_subnet_pool = mock.Mock(return_value=subnet_pool)
+        arglist = [
+            '--subnet-pool', subnet_pool.id,
+        ]
+        verifylist = [
+            ('subnet_pool', subnet_pool.id),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+        filters = {'subnetpool_id': subnet_pool.id}
+
+        self.network.subnets.assert_called_once_with(**filters)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.data, list(data))
+
     def test_list_with_tag_options(self):
         arglist = [
             '--tags', 'red,blue',
@@ -1143,8 +1185,8 @@ class TestSetSubnet(TestSubnet):
         self._test_set_tags(with_tags=False)
 
     def test_set_segment(self):
-        _net = network_fakes.FakeNetwork.create_one_network()
-        _segment = network_fakes.FakeNetworkSegment.create_one_network_segment(
+        _net = network_fakes.create_one_network()
+        _segment = network_fakes.create_one_network_segment(
             attrs={'network_id': _net.id})
         _subnet = network_fakes.FakeSubnet.create_one_subnet(
             {'host_routes': [{'destination': '10.20.20.0/24',
@@ -1205,7 +1247,7 @@ class TestShowSubnet(TestSubnet):
         _subnet.ipv6_ra_mode,
         _subnet.name,
         _subnet.network_id,
-        _subnet.tenant_id,
+        _subnet.project_id,
         _subnet.segment_id,
         format_columns.ListColumn(_subnet.service_types),
         _subnet.subnetpool_id,
