@@ -31,7 +31,7 @@ from openstackclient.volume.v1 import volume
 class TestVolume(volume_fakes.TestVolumev1):
 
     def setUp(self):
-        super(TestVolume, self).setUp()
+        super().setUp()
 
         # Get a shortcut to the VolumeManager Mock
         self.volumes_mock = self.app.client_manager.volume.volumes
@@ -50,11 +50,9 @@ class TestVolume(volume_fakes.TestVolumev1):
         self.images_mock.reset_mock()
 
     def setup_volumes_mock(self, count):
-        volumes = volume_fakes.FakeVolume.create_volumes(count=count)
+        volumes = volume_fakes.create_volumes(count=count)
 
-        self.volumes_mock.get = volume_fakes.FakeVolume.get_volumes(
-            volumes,
-            0)
+        self.volumes_mock.get = volume_fakes.get_volumes(volumes, 0)
         return volumes
 
 
@@ -79,8 +77,8 @@ class TestVolumeCreate(TestVolume):
     )
 
     def setUp(self):
-        super(TestVolumeCreate, self).setUp()
-        self.new_volume = volume_fakes.FakeVolume.create_one_volume()
+        super().setUp()
+        self.new_volume = volume_fakes.create_one_volume()
         self.datalist = (
             self.new_volume.attachments,
             self.new_volume.availability_zone,
@@ -317,7 +315,7 @@ class TestVolumeCreate(TestVolume):
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_id(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.images_mock.get.return_value = image
 
         arglist = [
@@ -360,7 +358,7 @@ class TestVolumeCreate(TestVolume):
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_name(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.images_mock.get.return_value = image
 
         arglist = [
@@ -432,7 +430,8 @@ class TestVolumeCreate(TestVolume):
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
-    def test_volume_create_with_bootable_and_readonly(self):
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
+    def test_volume_create_with_bootable_and_readonly(self, mock_wait):
         arglist = [
             '--bootable',
             '--read-only',
@@ -474,7 +473,8 @@ class TestVolumeCreate(TestVolume):
         self.volumes_mock.update_readonly_flag.assert_called_with(
             self.new_volume.id, True)
 
-    def test_volume_create_with_nonbootable_and_readwrite(self):
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
+    def test_volume_create_with_nonbootable_and_readwrite(self, mock_wait):
         arglist = [
             '--non-bootable',
             '--read-write',
@@ -517,8 +517,9 @@ class TestVolumeCreate(TestVolume):
             self.new_volume.id, False)
 
     @mock.patch.object(volume.LOG, 'error')
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
     def test_volume_create_with_bootable_and_readonly_fail(
-            self, mock_error):
+            self, mock_wait, mock_error):
 
         self.volumes_mock.set_bootable.side_effect = (
             exceptions.CommandError())
@@ -568,6 +569,48 @@ class TestVolumeCreate(TestVolume):
         self.volumes_mock.update_readonly_flag.assert_called_with(
             self.new_volume.id, True)
 
+    @mock.patch.object(volume.LOG, 'error')
+    @mock.patch.object(utils, 'wait_for_status', return_value=False)
+    def test_volume_create_non_available_with_readonly(
+            self, mock_wait, mock_error):
+        arglist = [
+            '--non-bootable',
+            '--read-only',
+            '--size', str(self.new_volume.size),
+            self.new_volume.display_name,
+        ]
+        verifylist = [
+            ('bootable', False),
+            ('non_bootable', True),
+            ('read_only', True),
+            ('read_write', False),
+            ('size', self.new_volume.size),
+            ('name', self.new_volume.display_name),
+        ]
+
+        parsed_args = self.check_parser(
+            self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.create.assert_called_with(
+            self.new_volume.size,
+            None,
+            None,
+            self.new_volume.display_name,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+            None,
+        )
+
+        self.assertEqual(2, mock_error.call_count)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
     def test_volume_create_without_size(self):
         arglist = [
             self.new_volume.display_name,
@@ -635,7 +678,7 @@ class TestVolumeCreate(TestVolume):
 class TestVolumeDelete(TestVolume):
 
     def setUp(self):
-        super(TestVolumeDelete, self).setUp()
+        super().setUp()
 
         self.volumes_mock.delete.return_value = None
 
@@ -725,7 +768,7 @@ class TestVolumeDelete(TestVolume):
 
 class TestVolumeList(TestVolume):
 
-    _volume = volume_fakes.FakeVolume.create_one_volume()
+    _volume = volume_fakes.create_one_volume()
     columns = (
         'ID',
         'Name',
@@ -744,7 +787,7 @@ class TestVolumeList(TestVolume):
     )
 
     def setUp(self):
-        super(TestVolumeList, self).setUp()
+        super().setUp()
 
         self.volumes_mock.list.return_value = [self._volume]
 
@@ -921,10 +964,10 @@ class TestVolumeList(TestVolume):
 
 class TestVolumeMigrate(TestVolume):
 
-    _volume = volume_fakes.FakeVolume.create_one_volume()
+    _volume = volume_fakes.create_one_volume()
 
     def setUp(self):
-        super(TestVolumeMigrate, self).setUp()
+        super().setUp()
 
         self.volumes_mock.get.return_value = self._volume
         self.volumes_mock.migrate_volume.return_value = None
@@ -983,10 +1026,10 @@ class TestVolumeMigrate(TestVolume):
 
 class TestVolumeSet(TestVolume):
 
-    _volume = volume_fakes.FakeVolume.create_one_volume()
+    _volume = volume_fakes.create_one_volume()
 
     def setUp(self):
-        super(TestVolumeSet, self).setUp()
+        super().setUp()
 
         self.volumes_mock.get.return_value = self._volume
 
@@ -1243,8 +1286,8 @@ class TestVolumeShow(TestVolume):
     )
 
     def setUp(self):
-        super(TestVolumeShow, self).setUp()
-        self._volume = volume_fakes.FakeVolume.create_one_volume()
+        super().setUp()
+        self._volume = volume_fakes.create_one_volume()
         self.datalist = (
             self._volume.attachments,
             self._volume.availability_zone,
@@ -1300,10 +1343,10 @@ class TestVolumeShow(TestVolume):
 
 class TestVolumeUnset(TestVolume):
 
-    _volume = volume_fakes.FakeVolume.create_one_volume()
+    _volume = volume_fakes.create_one_volume()
 
     def setUp(self):
-        super(TestVolumeUnset, self).setUp()
+        super().setUp()
 
         self.volumes_mock.get.return_value = self._volume
 
@@ -1346,7 +1389,7 @@ class TestVolumeUnset(TestVolume):
 class TestColumns(TestVolume):
 
     def test_attachments_column_without_server_cache(self):
-        _volume = volume_fakes.FakeVolume.create_one_volume()
+        _volume = volume_fakes.create_one_volume()
         server_id = _volume.attachments[0]['server_id']
         device = _volume.attachments[0]['device']
 
@@ -1356,7 +1399,7 @@ class TestColumns(TestVolume):
         self.assertEqual(_volume.attachments, col.machine_readable())
 
     def test_attachments_column_with_server_cache(self):
-        _volume = volume_fakes.FakeVolume.create_one_volume()
+        _volume = volume_fakes.create_one_volume()
 
         server_id = _volume.attachments[0]['server_id']
         device = _volume.attachments[0]['device']
