@@ -16,6 +16,7 @@ import argparse
 from unittest import mock
 from unittest.mock import call
 
+from cinderclient import api_versions
 from osc_lib.cli import format_columns
 from osc_lib import exceptions
 from osc_lib import utils
@@ -30,7 +31,7 @@ from openstackclient.volume.v2 import volume
 class TestVolume(volume_fakes.TestVolume):
 
     def setUp(self):
-        super(TestVolume, self).setUp()
+        super().setUp()
 
         self.volumes_mock = self.app.client_manager.volume.volumes
         self.volumes_mock.reset_mock()
@@ -47,6 +48,9 @@ class TestVolume(volume_fakes.TestVolume):
         self.snapshots_mock = self.app.client_manager.volume.volume_snapshots
         self.snapshots_mock.reset_mock()
 
+        self.backups_mock = self.app.client_manager.volume.backups
+        self.backups_mock.reset_mock()
+
         self.types_mock = self.app.client_manager.volume.volume_types
         self.types_mock.reset_mock()
 
@@ -55,11 +59,9 @@ class TestVolume(volume_fakes.TestVolume):
         self.consistencygroups_mock.reset_mock()
 
     def setup_volumes_mock(self, count):
-        volumes = volume_fakes.FakeVolume.create_volumes(count=count)
+        volumes = volume_fakes.create_volumes(count=count)
 
-        self.volumes_mock.get = volume_fakes.FakeVolume.get_volumes(
-            volumes,
-            0)
+        self.volumes_mock.get = volume_fakes.get_volumes(volumes, 0)
         return volumes
 
 
@@ -83,9 +85,9 @@ class TestVolumeCreate(TestVolume):
     )
 
     def setUp(self):
-        super(TestVolumeCreate, self).setUp()
+        super().setUp()
 
-        self.new_volume = volume_fakes.FakeVolume.create_one_volume()
+        self.new_volume = volume_fakes.create_one_volume()
         self.volumes_mock.create.return_value = self.new_volume
 
         self.datalist = (
@@ -108,11 +110,9 @@ class TestVolumeCreate(TestVolume):
     def test_volume_create_min_options(self):
         arglist = [
             '--size', str(self.new_volume.size),
-            self.new_volume.name,
         ]
         verifylist = [
             ('size', self.new_volume.size),
-            ('name', self.new_volume.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
@@ -124,7 +124,7 @@ class TestVolumeCreate(TestVolume):
         self.volumes_mock.create.assert_called_with(
             size=self.new_volume.size,
             snapshot_id=None,
-            name=self.new_volume.name,
+            name=None,
             description=None,
             volume_type=None,
             availability_zone=None,
@@ -133,14 +133,14 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_options(self):
-        consistency_group = (
-            volume_fakes.FakeConsistencyGroup.create_one_consistency_group())
+        consistency_group = volume_fakes.create_one_consistency_group()
         self.consistencygroups_mock.get.return_value = consistency_group
         arglist = [
             '--size', str(self.new_volume.size),
@@ -179,6 +179,7 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=consistency_group.id,
             scheduler_hints={'k': 'v'},
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
@@ -215,13 +216,14 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_id(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.find_image_mock.return_value = image
 
         arglist = [
@@ -253,13 +255,14 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_image_name(self):
-        image = image_fakes.FakeImage.create_one_image()
+        image = image_fakes.create_one_image()
         self.find_image_mock.return_value = image
 
         arglist = [
@@ -291,13 +294,14 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
     def test_volume_create_with_snapshot(self):
-        snapshot = volume_fakes.FakeSnapshot.create_one_snapshot()
+        snapshot = volume_fakes.create_one_snapshot()
         self.new_volume.snapshot_id = snapshot.id
         arglist = [
             '--snapshot', self.new_volume.snapshot_id,
@@ -328,12 +332,111 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
         self.assertCountEqual(self.datalist, data)
 
-    def test_volume_create_with_bootable_and_readonly(self):
+    def test_volume_create_with_backup(self):
+        backup = volume_fakes.create_one_backup()
+        self.new_volume.backup_id = backup.id
+        arglist = [
+            '--backup', self.new_volume.backup_id,
+            self.new_volume.name,
+        ]
+        verifylist = [
+            ('backup', self.new_volume.backup_id),
+            ('name', self.new_volume.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.backups_mock.get.return_value = backup
+
+        self.app.client_manager.volume.api_version = \
+            api_versions.APIVersion('3.47')
+
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.create.assert_called_once_with(
+            size=backup.size,
+            snapshot_id=None,
+            name=self.new_volume.name,
+            description=None,
+            volume_type=None,
+            availability_zone=None,
+            metadata=None,
+            imageRef=None,
+            source_volid=None,
+            consistencygroup_id=None,
+            scheduler_hints=None,
+            backup_id=backup.id,
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    def test_volume_create_with_backup_pre_347(self):
+        backup = volume_fakes.create_one_backup()
+        self.new_volume.backup_id = backup.id
+        arglist = [
+            '--backup', self.new_volume.backup_id,
+            self.new_volume.name,
+        ]
+        verifylist = [
+            ('backup', self.new_volume.backup_id),
+            ('name', self.new_volume.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.backups_mock.get.return_value = backup
+
+        exc = self.assertRaises(exceptions.CommandError, self.cmd.take_action,
+                                parsed_args)
+        self.assertIn("--os-volume-api-version 3.47 or greater", str(exc))
+
+    def test_volume_create_with_source_volume(self):
+        source_vol = "source_vol"
+        arglist = [
+            '--source', self.new_volume.id,
+            source_vol,
+        ]
+        verifylist = [
+            ('source', self.new_volume.id),
+            ('name', source_vol),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        self.volumes_mock.get.return_value = self.new_volume
+
+        # In base command class ShowOne in cliff, abstract method take_action()
+        # returns a two-part tuple with a tuple of column names and a tuple of
+        # data to be shown.
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.create.assert_called_once_with(
+            size=self.new_volume.size,
+            snapshot_id=None,
+            name=source_vol,
+            description=None,
+            volume_type=None,
+            availability_zone=None,
+            metadata=None,
+            imageRef=None,
+            source_volid=self.new_volume.id,
+            consistencygroup_id=None,
+            scheduler_hints=None,
+            backup_id=None,
+        )
+
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
+    def test_volume_create_with_bootable_and_readonly(self, mock_wait):
         arglist = [
             '--bootable',
             '--read-only',
@@ -366,6 +469,7 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
@@ -375,7 +479,8 @@ class TestVolumeCreate(TestVolume):
         self.volumes_mock.update_readonly_flag.assert_called_with(
             self.new_volume.id, True)
 
-    def test_volume_create_with_nonbootable_and_readwrite(self):
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
+    def test_volume_create_with_nonbootable_and_readwrite(self, mock_wait):
         arglist = [
             '--non-bootable',
             '--read-write',
@@ -408,6 +513,7 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(self.columns, columns)
@@ -418,8 +524,9 @@ class TestVolumeCreate(TestVolume):
             self.new_volume.id, False)
 
     @mock.patch.object(volume.LOG, 'error')
+    @mock.patch.object(utils, 'wait_for_status', return_value=True)
     def test_volume_create_with_bootable_and_readonly_fail(
-            self, mock_error):
+            self, mock_wait, mock_error):
 
         self.volumes_mock.set_bootable.side_effect = (
             exceptions.CommandError())
@@ -459,6 +566,7 @@ class TestVolumeCreate(TestVolume):
             source_volid=None,
             consistencygroup_id=None,
             scheduler_hints=None,
+            backup_id=None,
         )
 
         self.assertEqual(2, mock_error.call_count)
@@ -469,6 +577,50 @@ class TestVolumeCreate(TestVolume):
         self.volumes_mock.update_readonly_flag.assert_called_with(
             self.new_volume.id, True)
 
+    @mock.patch.object(volume.LOG, 'error')
+    @mock.patch.object(utils, 'wait_for_status', return_value=False)
+    def test_volume_create_non_available_with_readonly(
+        self, mock_wait, mock_error,
+    ):
+        arglist = [
+            '--non-bootable',
+            '--read-only',
+            '--size', str(self.new_volume.size),
+            self.new_volume.name,
+        ]
+        verifylist = [
+            ('bootable', False),
+            ('non_bootable', True),
+            ('read_only', True),
+            ('read_write', False),
+            ('size', self.new_volume.size),
+            ('name', self.new_volume.name),
+        ]
+
+        parsed_args = self.check_parser(
+            self.cmd, arglist, verifylist)
+
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.volumes_mock.create.assert_called_with(
+            size=self.new_volume.size,
+            snapshot_id=None,
+            name=self.new_volume.name,
+            description=None,
+            volume_type=None,
+            availability_zone=None,
+            metadata=None,
+            imageRef=None,
+            source_volid=None,
+            consistencygroup_id=None,
+            scheduler_hints=None,
+            backup_id=None,
+        )
+
+        self.assertEqual(2, mock_error.call_count)
+        self.assertEqual(self.columns, columns)
+        self.assertCountEqual(self.datalist, data)
+
     def test_volume_create_without_size(self):
         arglist = [
             self.new_volume.name,
@@ -504,7 +656,7 @@ class TestVolumeCreate(TestVolume):
 class TestVolumeDelete(TestVolume):
 
     def setUp(self):
-        super(TestVolumeDelete, self).setUp()
+        super().setUp()
 
         self.volumes_mock.delete.return_value = None
 
@@ -632,9 +784,9 @@ class TestVolumeList(TestVolume):
     ]
 
     def setUp(self):
-        super(TestVolumeList, self).setUp()
+        super().setUp()
 
-        self.mock_volume = volume_fakes.FakeVolume.create_one_volume()
+        self.mock_volume = volume_fakes.create_one_volume()
         self.volumes_mock.list.return_value = [self.mock_volume]
 
         self.users_mock.get.return_value = self.user
@@ -1107,10 +1259,10 @@ class TestVolumeList(TestVolume):
 
 class TestVolumeMigrate(TestVolume):
 
-    _volume = volume_fakes.FakeVolume.create_one_volume()
+    _volume = volume_fakes.create_one_volume()
 
     def setUp(self):
-        super(TestVolumeMigrate, self).setUp()
+        super().setUp()
 
         self.volumes_mock.get.return_value = self._volume
         self.volumes_mock.migrate_volume.return_value = None
@@ -1173,12 +1325,12 @@ class TestVolumeMigrate(TestVolume):
 
 class TestVolumeSet(TestVolume):
 
-    volume_type = volume_fakes.FakeVolumeType.create_one_volume_type()
+    volume_type = volume_fakes.create_one_volume_type()
 
     def setUp(self):
-        super(TestVolumeSet, self).setUp()
+        super().setUp()
 
-        self.new_volume = volume_fakes.FakeVolume.create_one_volume()
+        self.new_volume = volume_fakes.create_one_volume()
         self.volumes_mock.get.return_value = self.new_volume
         self.types_mock.get.return_value = self.volume_type
 
@@ -1427,9 +1579,9 @@ class TestVolumeSet(TestVolume):
 class TestVolumeShow(TestVolume):
 
     def setUp(self):
-        super(TestVolumeShow, self).setUp()
+        super().setUp()
 
-        self._volume = volume_fakes.FakeVolume.create_one_volume()
+        self._volume = volume_fakes.create_one_volume()
         self.volumes_mock.get.return_value = self._volume
         # Get the command object to test
         self.cmd = volume.ShowVolume(self.app, None)
@@ -1447,20 +1599,21 @@ class TestVolumeShow(TestVolume):
         self.volumes_mock.get.assert_called_with(self._volume.id)
 
         self.assertEqual(
-            volume_fakes.FakeVolume.get_volume_columns(self._volume),
-            columns)
-
+            volume_fakes.get_volume_columns(self._volume),
+            columns,
+        )
         self.assertCountEqual(
-            volume_fakes.FakeVolume.get_volume_data(self._volume),
-            data)
+            volume_fakes.get_volume_data(self._volume),
+            data,
+        )
 
 
 class TestVolumeUnset(TestVolume):
 
     def setUp(self):
-        super(TestVolumeUnset, self).setUp()
+        super().setUp()
 
-        self.new_volume = volume_fakes.FakeVolume.create_one_volume()
+        self.new_volume = volume_fakes.create_one_volume()
         self.volumes_mock.get.return_value = self.new_volume
 
         # Get the command object to set property
@@ -1538,7 +1691,7 @@ class TestVolumeUnset(TestVolume):
 class TestColumns(TestVolume):
 
     def test_attachments_column_without_server_cache(self):
-        _volume = volume_fakes.FakeVolume.create_one_volume()
+        _volume = volume_fakes.create_one_volume()
         server_id = _volume.attachments[0]['server_id']
         device = _volume.attachments[0]['device']
 
@@ -1548,7 +1701,7 @@ class TestColumns(TestVolume):
         self.assertEqual(_volume.attachments, col.machine_readable())
 
     def test_attachments_column_with_server_cache(self):
-        _volume = volume_fakes.FakeVolume.create_one_volume()
+        _volume = volume_fakes.create_one_volume()
 
         server_id = _volume.attachments[0]['server_id']
         device = _volume.attachments[0]['device']
