@@ -25,7 +25,6 @@ from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 
@@ -225,15 +224,44 @@ class CreateVolume(command.ShowOne):
 
         if parsed_args.bootable or parsed_args.non_bootable:
             try:
-                volume_client.volumes.set_bootable(
-                    volume.id, parsed_args.bootable)
+                if utils.wait_for_status(
+                    volume_client.volumes.get,
+                    volume.id,
+                    success_status=['available'],
+                    error_status=['error'],
+                    sleep_time=1
+                ):
+                    volume_client.volumes.set_bootable(
+                        volume.id,
+                        parsed_args.bootable
+                    )
+                else:
+                    msg = _(
+                        "Volume status is not available for setting boot "
+                        "state"
+                    )
+                    raise exceptions.CommandError(msg)
             except Exception as e:
                 LOG.error(_("Failed to set volume bootable property: %s"), e)
         if parsed_args.read_only or parsed_args.read_write:
             try:
-                volume_client.volumes.update_readonly_flag(
+                if utils.wait_for_status(
+                    volume_client.volumes.get,
                     volume.id,
-                    parsed_args.read_only)
+                    success_status=['available'],
+                    error_status=['error'],
+                    sleep_time=1
+                ):
+                    volume_client.volumes.update_readonly_flag(
+                        volume.id,
+                        parsed_args.read_only
+                    )
+                else:
+                    msg = _(
+                        "Volume status is not available for setting it"
+                        "read only."
+                    )
+                    raise exceptions.CommandError(msg)
             except Exception as e:
                 LOG.error(_("Failed to set volume read-only access "
                             "mode flag: %s"), e)
@@ -253,7 +281,7 @@ class CreateVolume(command.ShowOne):
             volume._info, parsed_args.columns, {'display_name': 'name'}
         )
 
-        return zip(*sorted(six.iteritems(volume_info)))
+        return zip(*sorted(volume_info.items()))
 
 
 class DeleteVolume(command.Command):
@@ -328,6 +356,13 @@ class ListVolume(command.Lister):
             default=False,
             help=_('List additional fields in output'),
         )
+        parser.add_argument(
+            '--offset',
+            type=int,
+            action=parseractions.NonNegativeAction,
+            metavar='<offset>',
+            help=_('Index from which to start listing volumes'),
+        )
         parser.add_argument(
             '--limit',
             type=int,
@@ -396,6 +431,9 @@ class ListVolume(command.Lister):
             'status': parsed_args.status,
         }
 
+        if parsed_args.offset:
+            search_opts['offset'] = parsed_args.offset
+
         data = volume_client.volumes.list(
             search_opts=search_opts,
             limit=parsed_args.limit,
@@ -614,7 +652,7 @@ class ShowVolume(command.ShowOne):
             volume._info, parsed_args.columns, {'display_name': 'name'}
         )
 
-        return zip(*sorted(six.iteritems(volume_info)))
+        return zip(*sorted(volume_info.items()))
 
 
 class UnsetVolume(command.Command):
