@@ -16,13 +16,15 @@
 
 import argparse
 import copy
+import functools
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -31,6 +33,37 @@ from openstackclient.identity import common as identity_common
 LOG = logging.getLogger(__name__)
 
 
+class AttachmentsColumn(cliff_columns.FormattableColumn):
+    """Formattable column for attachments column.
+
+    Unlike the parent FormattableColumn class, the initializer of the
+    class takes server_cache as the second argument.
+    osc_lib.utils.get_item_properties instantiate cliff FormattableColumn
+    object with a single parameter "column value", so you need to pass
+    a partially initialized class like
+    ``functools.partial(AttachmentsColumn, server_cache)``.
+    """
+
+    def __init__(self, value, server_cache=None):
+        super(AttachmentsColumn, self).__init__(value)
+        self._server_cache = server_cache or {}
+
+    def human_readable(self):
+        """Return a formatted string of a volume's attached instances
+
+        :rtype: a string of formatted instances
+        """
+
+        msg = ''
+        for attachment in self._value:
+            server = attachment['server_id']
+            if server in self._server_cache.keys():
+                server = self._server_cache[server].name
+            device = attachment['device']
+            msg += 'Attached to %s on %s ' % (server, device)
+        return msg
+
+
 def _check_size_arg(args):
     """Check whether --size option is required or not.
 
@@ -38,10 +71,10 @@ def _check_size_arg(args):
     volume is not specified.
     """
 
-    if ((args.snapshot or args.source)
+    if ((args.snapshot or args.source or args.backup)
             is None and args.size is None):
-        msg = _("--size is a required option if snapshot "
-                "or source volume is not specified.")
+        msg = _("--size is a required option if snapshot, backup "
+                "or source volume are not specified.")
         raise exceptions.CommandError(msg)
 
 
@@ -49,18 +82,19 @@ class CreateVolume(command.ShowOne):
     _description = _("Create new volume")
 
     def get_parser(self, prog_name):
-        parser = super(CreateVolume, self).get_parser(prog_name)
+        parser = super().get_parser(prog_name)
         parser.add_argument(
             "name",
             metavar="<name>",
+            nargs="?",
             help=_("Volume name"),
         )
         parser.add_argument(
             "--size",
             metavar="<size>",
             type=int,
-            help=_("Volume size in GB (Required unless --snapshot or "
-                   "--source is specified)"),
+            help=_("Volume size in GB (required unless --snapshot, "
+                   "--source or --backup is specified)"),
         )
         parser.add_argument(
             "--type",
@@ -83,6 +117,12 @@ class CreateVolume(command.ShowOne):
             metavar="<volume>",
             help=_("Volume to clone (name or ID)"),
         )
+        source_group.add_argument(
+            "--backup",
+            metavar="<backup>",
+            help=_("Restore backup to a volume (name or ID) "
+                   "(supported by --os-volume-api-version 3.47 or later)"),
+        )
         source_group.add_argument(
             "--source-replicated",
             metavar="<replicated-volume>",
@@ -93,16 +133,6 @@ class CreateVolume(command.ShowOne):
             metavar="<description>",
             help=_("Volume description"),
         )
-        parser.add_argument(
-            '--user',
-            metavar='<user>',
-            help=argparse.SUPPRESS,
-        )
-        parser.add_argument(
-            '--project',
-            metavar='<project>',
-            help=argparse.SUPPRESS,
-        )
         parser.add_argument(
             "--availability-zone",
             metavar="<availability-zone>",
@@ -127,12 +157,6 @@ class CreateVolume(command.ShowOne):
             help=_("Arbitrary scheduler hint key-value pairs to help boot "
                    "an instance (repeat option to set multiple hints)"),
         )
-        parser.add_argument(
-            "--multi-attach",
-            action="store_true",
-            help=_("Allow volume to be attached more than once "
-                   "(default to False)")
-        )
         bootable_group = parser.add_mutually_exclusive_group()
         bootable_group.add_argument(
             "--bootable",
@@ -159,14 +183,28 @@ class CreateVolume(command.ShowOne):
 
     def take_action(self, parsed_args):
         _check_size_arg(parsed_args)
+        # size is validated in the above call to
+        # _check_size_arg where we check that size
+        # should be passed if we are not creating a
+        # volume from snapshot, backup or source volume
+        size = parsed_args.size
+
         volume_client = self.app.client_manager.volume
         image_client = self.app.client_manager.image
 
+        if parsed_args.backup and not (
+                volume_client.api_version.matches('3.47')):
+            msg = _("--os-volume-api-version 3.47 or greater is required "
+                    "to create a volume from backup.")
+            raise exceptions.CommandError(msg)
+
         source_volume = None
         if parsed_args.source:
-            source_volume = utils.find_resource(
+            source_volume_obj = utils.find_resource(
                 volume_client.volumes,
-                parsed_args.source).id
+                parsed_args.source)
+            source_volume = source_volume_obj.id
+            size = max(size or 0, source_volume_obj.size)
 
         consistency_group = None
         if parsed_args.consistency_group:
@@ -176,11 +214,8 @@ class CreateVolume(command.ShowOne):
 
         image = None
         if parsed_args.image:
-            image = utils.find_resource(
-                image_client.images,
-                parsed_args.image).id
-
-        size = parsed_args.size
+            image = image_client.find_image(parsed_args.image,
+                                            ignore_missing=False).id
 
         snapshot = None
         if parsed_args.snapshot:
@@ -196,25 +231,14 @@ class CreateVolume(command.ShowOne):
             # snapshot size.
             size = max(size or 0, snapshot_obj.size)
 
-        # NOTE(abishop): Cinder's volumes.create() has 'project_id' and
-        # 'user_id' args, but they're not wired up to anything. The only way
-        # to specify an alternate project or user for the volume is to use
-        # the identity overrides (e.g. "--os-project-id").
-        #
-        # Now, if the project or user arg is specified then the command is
-        # rejected. Otherwise, Cinder would actually create a volume, but
-        # without the specified property.
-        if parsed_args.project:
-            raise exceptions.CommandError(
-                _("ERROR: --project is deprecated, please use"
-                  " --os-project-name or --os-project-id instead."))
-        if parsed_args.user:
-            raise exceptions.CommandError(
-                _("ERROR: --user is deprecated, please use"
-                  " --os-username instead."))
-        if parsed_args.multi_attach:
-            LOG.warning(_("'--multi-attach' option is no longer supported by "
-                          "the block storage service."))
+        backup = None
+        if parsed_args.backup:
+            backup_obj = utils.find_resource(
+                volume_client.backups,
+                parsed_args.backup)
+            backup = backup_obj.id
+            # As above
+            size = max(size or 0, backup_obj.size)
 
         volume = volume_client.volumes.create(
             size=size,
@@ -228,19 +252,49 @@ class CreateVolume(command.ShowOne):
             source_volid=source_volume,
             consistencygroup_id=consistency_group,
             scheduler_hints=parsed_args.hint,
+            backup_id=backup,
         )
 
         if parsed_args.bootable or parsed_args.non_bootable:
             try:
-                volume_client.volumes.set_bootable(
-                    volume.id, parsed_args.bootable)
+                if utils.wait_for_status(
+                    volume_client.volumes.get,
+                    volume.id,
+                    success_status=['available'],
+                    error_status=['error'],
+                    sleep_time=1
+                ):
+                    volume_client.volumes.set_bootable(
+                        volume.id,
+                        parsed_args.bootable
+                    )
+                else:
+                    msg = _(
+                        "Volume status is not available for setting boot "
+                        "state"
+                    )
+                    raise exceptions.CommandError(msg)
             except Exception as e:
                 LOG.error(_("Failed to set volume bootable property: %s"), e)
         if parsed_args.read_only or parsed_args.read_write:
             try:
-                volume_client.volumes.update_readonly_flag(
+                if utils.wait_for_status(
+                    volume_client.volumes.get,
                     volume.id,
-                    parsed_args.read_only)
+                    success_status=['available'],
+                    error_status=['error'],
+                    sleep_time=1
+                ):
+                    volume_client.volumes.update_readonly_flag(
+                        volume.id,
+                        parsed_args.read_only
+                    )
+                else:
+                    msg = _(
+                        "Volume status is not available for setting it"
+                        "read only."
+                    )
+                    raise exceptions.CommandError(msg)
             except Exception as e:
                 LOG.error(_("Failed to set volume read-only access "
                             "mode flag: %s"), e)
@@ -248,12 +302,13 @@ class CreateVolume(command.ShowOne):
         # Remove key links from being displayed
         volume._info.update(
             {
-                'properties': utils.format_dict(volume._info.pop('metadata')),
+                'properties':
+                format_columns.DictColumn(volume._info.pop('metadata')),
                 'type': volume._info.pop('volume_type')
             }
         )
         volume._info.pop("links", None)
-        return zip(*sorted(six.iteritems(volume._info)))
+        return zip(*sorted(volume._info.items()))
 
 
 class DeleteVolume(command.Command):
@@ -364,25 +419,8 @@ class ListVolume(command.Lister):
     def take_action(self, parsed_args):
 
         volume_client = self.app.client_manager.volume
-        compute_client = self.app.client_manager.compute
         identity_client = self.app.client_manager.identity
 
-        def _format_attach(attachments):
-            """Return a formatted string of a volume's attached instances
-
-            :param attachments: a volume.attachments field
-            :rtype: a string of formatted instances
-            """
-
-            msg = ''
-            for attachment in attachments:
-                server = attachment['server_id']
-                if server in server_cache:
-                    server = server_cache[server].name
-                device = attachment['device']
-                msg += 'Attached to %s on %s ' % (server, device)
-            return msg
-
         if parsed_args.long:
             columns = [
                 'ID',
@@ -412,11 +450,14 @@ class ListVolume(command.Lister):
         # Cache the server list
         server_cache = {}
         try:
+            compute_client = self.app.client_manager.compute
             for s in compute_client.servers.list():
                 server_cache[s.id] = s
         except Exception:
             # Just forget it if there's any trouble
             pass
+        AttachmentsColumnWithCache = functools.partial(
+            AttachmentsColumn, server_cache=server_cache)
 
         project_id = None
         if parsed_args.project:
@@ -453,8 +494,8 @@ class ListVolume(command.Lister):
         return (column_headers,
                 (utils.get_item_properties(
                     s, columns,
-                    formatters={'Metadata': utils.format_dict,
-                                'Attachments': _format_attach},
+                    formatters={'Metadata': format_columns.DictColumn,
+                                'Attachments': AttachmentsColumnWithCache},
                 ) for s in data))
 
 
@@ -622,14 +663,16 @@ class SetVolume(command.Command):
         result = 0
         if parsed_args.size:
             try:
-                if volume.status != 'available':
-                    msg = (_("Volume is in %s state, it must be available "
-                           "before size can be extended") % volume.status)
-                    raise exceptions.CommandError(msg)
                 if parsed_args.size <= volume.size:
                     msg = (_("New size must be greater than %s GB")
                            % volume.size)
                     raise exceptions.CommandError(msg)
+                if volume.status != 'available' and \
+                        not volume_client.api_version.matches('3.42'):
+
+                    msg = (_("Volume is in %s state, it must be available "
+                           "before size can be extended") % volume.status)
+                    raise exceptions.CommandError(msg)
                 volume_client.volumes.extend(volume.id, parsed_args.size)
             except Exception as e:
                 LOG.error(_("Failed to set volume size: %s"), e)
@@ -758,14 +801,15 @@ class ShowVolume(command.ShowOne):
         # 'volume_type' --> 'type'
         volume._info.update(
             {
-                'properties': utils.format_dict(volume._info.pop('metadata')),
+                'properties':
+                format_columns.DictColumn(volume._info.pop('metadata')),
                 'type': volume._info.pop('volume_type'),
             },
         )
 
         # Remove key links from being displayed
         volume._info.pop("links", None)
-        return zip(*sorted(six.iteritems(volume._info)))
+        return zip(*sorted(volume._info.items()))
 
 
 class UnsetVolume(command.Command):
