@@ -24,7 +24,6 @@ from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
-import six
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
@@ -99,7 +98,7 @@ class CreateVolumeSnapshot(command.ShowOne):
             "--remote-source",
             metavar="<key=value>",
             action=parseractions.KeyValueAction,
-            help=_("The attribute(s) of the exsiting remote volume snapshot "
+            help=_("The attribute(s) of the existing remote volume snapshot "
                    "(admin required) (repeat option to specify multiple "
                    "attributes) e.g.: '--remote-source source-name=test_name "
                    "--remote-source source-id=test_id'"),
@@ -140,7 +139,7 @@ class CreateVolumeSnapshot(command.ShowOne):
             {'properties':
              format_columns.DictColumn(snapshot._info.pop('metadata'))}
         )
-        return zip(*sorted(six.iteritems(snapshot._info)))
+        return zip(*sorted(snapshot._info.items()))
 
 
 class DeleteVolumeSnapshot(command.Command):
@@ -230,10 +229,10 @@ class ListVolumeSnapshot(command.Lister):
             '--status',
             metavar='<status>',
             choices=['available', 'error', 'creating', 'deleting',
-                     'error-deleting'],
+                     'error_deleting'],
             help=_("Filters results by a status. "
                    "('available', 'error', 'creating', 'deleting'"
-                   " or 'error-deleting')")
+                   " or 'error_deleting')")
         )
         parser.add_argument(
             '--volume',
@@ -345,7 +344,7 @@ class SetVolumeSnapshot(command.Command):
             '--state',
             metavar='<state>',
             choices=['available', 'error', 'creating', 'deleting',
-                     'error-deleting'],
+                     'error_deleting'],
             help=_('New snapshot state. ("available", "error", "creating", '
                    '"deleting", or "error_deleting") (admin only) '
                    '(This option simply changes the state of the snapshot '
@@ -426,7 +425,7 @@ class ShowVolumeSnapshot(command.ShowOne):
             {'properties':
              format_columns.DictColumn(snapshot._info.pop('metadata'))}
         )
-        return zip(*sorted(six.iteritems(snapshot._info)))
+        return zip(*sorted(snapshot._info.items()))
 
 
 class UnsetVolumeSnapshot(command.Command):
